@@ -37,8 +37,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 323 2007-07-26 22:24:04Z CodyPrecord $"
-__revision__ = "$Revision: 323 $"
+__svnid__ = "$Id: Editra.py 549 2007-09-28 07:55:35Z CodyPrecord $"
+__revision__ = "$Revision: 549 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -55,13 +55,14 @@ import dev_tool
 import ed_main
 import ed_art
 import plugin
+import extern.events as events
 
 #--------------------------------------------------------------------------#
 # Global Variables
 
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
-class Editra(wx.App):
+class Editra(wx.App, events.AppEventHandlerMixin):
     """The Editra Application Object
     @see: L{wx.App}
 
@@ -72,7 +73,8 @@ class Editra(wx.App):
 
         """
         wx.App.__init__(self, *args, **kargs)
-        
+        events.AppEventHandlerMixin.__init__(self)
+
         # Attributes
         self._log = dev_tool.DEBUGP
         self._lock = False
@@ -85,7 +87,7 @@ class Editra(wx.App):
         @postcondition: custom artprovider and plugins are loaded
 
         """
-        self.SetAppName(ed_glob.prog_name)
+        self.SetAppName(ed_glob.PROG_NAME)
         self._log = dev_tool.DEBUGP
         self._log("[app][info] Registering Editra's ArtProvider")
         wx.ArtProvider.PushProvider(ed_art.EditraArt())
@@ -95,17 +97,18 @@ class Editra(wx.App):
 
         #---- Bind Events ----#
         self.Bind(wx.EVT_ACTIVATE_APP, self.OnActivate)
+        self.Bind(wx.EVT_MENU, self.OnNewWindow, id=ed_glob.ID_NEW_WINDOW)
 
         return True
 
-    def Exit(self):
+    def Exit(self, force=False):
         """Exit the program
         @postcondition: If no toplevel windows are precent program will exit.
         @postcondition: Program may remain open if an open window is locking.
 
         """
         self._pluginmgr.WritePluginConfig()
-        if not self._lock:
+        if not self._lock or force:
             wx.App.Exit(self)
 
     def GetLog(self):
@@ -121,6 +124,7 @@ class Editra(wx.App):
         @return: the L{MainWindow} of this app if it is open
         
         """
+        self._log("[app][warn] Editra::GetMainWindow is deprecated")
         for window in self._windows:
             if not hasattr(self._windows[window][0], '__name__'):
                 continue
@@ -128,6 +132,38 @@ class Editra(wx.App):
                 return self._windows[window][0]
         return None
 
+    def GetActiveWindow(self):
+        """Returns the active main window if there is one else it will
+        just return some main window or none if there are no main windows
+        @return: frame instance or None
+
+        """
+        awin = None
+        for win in self.GetMainWindows():
+            if win.IsActive():
+                awin = win
+                break
+
+        if awin is None:
+            if len(self.GetMainWindows()):
+                awin = self.GetMainWindows()[0]
+
+        return awin
+
+    def GetMainWindows(self):
+        """Returns a list of all open main windows
+        @return: list of L{MainWindow} instances of this app (list may be empty)
+        
+        """
+        mainw = list()
+        for window in self._windows:
+            try:
+                if self._windows[window][0].__name__ == "MainWindow":
+                    mainw.append(self._windows[window][0])
+            except AttributeError:
+                continue
+        return mainw
+
     def GetOpenWindows(self):
         """Returns a list of open windows
         @return: list of all open windows owned by app
@@ -180,7 +216,7 @@ class Editra(wx.App):
         window = self.GetTopWindow()
         if window != None and window.__name__ == "MainWindow":
             try:
-                window.DoOpen(wx.ID_ANY, unicode(filename.decode('utf-8')))
+                window.DoOpen(wx.ID_ANY, util.DecodeString(filename))
                 self._log("[app][info] MacOpenFile Fired")
             finally:
                 pass
@@ -199,6 +235,64 @@ class Editra(wx.App):
             self._log("[app][info] Going to sleep")
         evt.Skip()
 
+    def OnExit(self, evt=None, force=False):
+        """Handle application exit request
+        @param evt: event that called this handler
+
+        """
+        e_id = -1
+        if evt:
+            e_id = evt.GetId()
+        if e_id == ed_glob.ID_EXIT:
+            # First loop is to ensure current top window is
+            # closed first
+            for win in self.GetMainWindows():
+                if win.IsActive():
+                    result = win.Close()
+                    if result:
+                        break
+                    return
+            for win in self.GetMainWindows():
+                win.Raise()
+                result = win.Close()
+                if not result:
+                    break
+            self.Exit(force)
+        else:
+            if evt:
+                evt.Skip()
+
+    def OnNewWindow(self, evt):
+        """Create a new editing window
+        @param evt: wx.EVT_MENU
+
+        """
+        if evt.GetId() == ed_glob.ID_NEW_WINDOW:
+            frame = evt.GetEventObject().GetMenuBar().GetFrame()
+            self.OpenNewWindow(caller=frame)
+        else:
+            evt.Skip()
+
+    def OpenNewWindow(self, fname=u'', caller=None):
+        """Open a new window
+        @keyword fname: Open a file in the new window
+
+        """
+        frame = ed_main.MainWindow(None, wx.ID_ANY, Profile_Get('WSIZE'), 
+                                   ed_glob.PROG_NAME)
+        if caller:
+            pos = caller.GetPosition()
+            frame.SetPosition((pos.x + 22, pos.y + 22))
+        self.RegisterWindow(repr(frame), frame, True)
+        self.SetTopWindow(frame)
+        if isinstance(fname, basestring) and fname != u'':
+            frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, fname)
+        frame.Show(True)
+        
+        # Ensure frame gets an Activate event when shown
+        # this doesn't happen automatically on windows
+        wx.PostEvent(frame, wx.ActivateEvent(wx.wxEVT_ACTIVATE, True))
+
     def RegisterWindow(self, name, window, can_lock=False):
         """Registers winows with the app. The name should be the
         repr of window. The can_lock parameter is a boolean stating
@@ -315,8 +409,6 @@ def InitConfig():
     ed_glob.CONFIG['CONFIG_DIR'] = util.ResolvConfigDir("")
     ed_glob.CONFIG['PIXMAPS_DIR'] = util.ResolvConfigDir("pixmaps")
     ed_glob.CONFIG['SYSPIX_DIR'] = util.ResolvConfigDir("pixmaps", True)
-    ed_glob.CONFIG['MIME_DIR'] = util.ResolvConfigDir(os.path.join("pixmaps", \
-                                                                  "mime"), True)
     ed_glob.CONFIG['PLUGIN_DIR'] = util.ResolvConfigDir("plugins")
     ed_glob.CONFIG['THEME_DIR'] = util.ResolvConfigDir(os.path.join("pixmaps", \
                                                                     "theme"))
@@ -366,11 +458,11 @@ def Main():
                    "  --help     Show this help message\n"
                    "  --oldPath  Don't use this!!\n"
                    "  --version  Print version number and exit\n"
-                  ) % ed_glob.version
+                  ) % ed_glob.VERSION
             exit(0)
         if True in [x[0] in ['-v', '--version'] for x in opts]:
-            print "%s - v%s - Developers Editor" % (ed_glob.prog_name, \
-                                                    ed_glob.version)
+            print "%s - v%s - Developers Editor" % (ed_glob.PROG_NAME, \
+                                                    ed_glob.VERSION)
             exit(0)
         if True in [x[0] in ['-d', '--debug'] for x in opts]:
             ed_glob.DEBUG = True
@@ -389,8 +481,8 @@ def Main():
     langid = ed_i18n.GetLangId(Profile_Get('LANG'))
     the_locale = wx.Locale(langid)
     the_locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
-    the_locale.AddCatalog(ed_glob.prog_name)
-    language = gettext.translation(ed_glob.prog_name, 
+    the_locale.AddCatalog(ed_glob.PROG_NAME)
+    language = gettext.translation(ed_glob.PROG_NAME, 
                                    ed_glob.CONFIG['LANG_DIR'],
                                    [the_locale.GetCanonicalName()], 
                                    fallback=True)
@@ -406,7 +498,7 @@ def Main():
                       _("Profile Updated"))
 
     # Splash a warning if version is not a final version
-    if Profile_Get('APPSPLASH') and int(ed_glob.version[0]) < 1:
+    if Profile_Get('APPSPLASH') and int(ed_glob.VERSION[0]) < 1:
         splash_img = wx.ArtProvider.GetBitmap(str(ed_glob.ID_APP_SPLASH), 
                                               wx.ART_OTHER)
         splash = wx.SplashScreen(splash_img, wx.SPLASH_CENTRE_ON_PARENT | \
@@ -415,16 +507,17 @@ def Main():
         wx.FutureCall(3000, splash.Destroy)
 
     frame = ed_main.MainWindow(None, wx.ID_ANY, Profile_Get('WSIZE'), 
-                                    ed_glob.prog_name)
+                               ed_glob.PROG_NAME)
     editra_app.RegisterWindow(repr(frame), frame, True)
     editra_app.SetTopWindow(frame)
+    frame.Show(True)
+    wx.PostEvent(frame, wx.ActivateEvent(wx.wxEVT_ACTIVATE, True))
 
     for arg in args:
         try:
             if not os.path.isabs(arg):
                 arg = os.path.abspath(arg)
-            frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, \
-                         unicode(arg.decode('utf-8')))
+            frame.DoOpen(ed_glob.ID_COMMAND_LINE_OPEN, util.DecodeString(arg))
         except IndexError:
             dev_tool.DEBUGP("[main][err] IndexError on commandline args")
 
