@@ -24,8 +24,8 @@
 
 """
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: dev_tool.py 344 2007-08-13 21:46:37Z CodyPrecord $"
-__revision__ = "$Revision: 344 $"
+__svnid__ = "$Id: dev_tool.py 549 2007-09-28 07:55:35Z CodyPrecord $"
+__revision__ = "$Revision: 549 $"
 
 import os
 import sys
@@ -95,7 +95,7 @@ def EnvironmentInfo():
     """
     info = list()
     info.append("#---- System Information ----#")
-    info.append("%s Version: %s" % (ed_glob.prog_name, ed_glob.version))
+    info.append("%s Version: %s" % (ed_glob.PROG_NAME, ed_glob.VERSION))
     info.append("Operating System: %s" % wx.GetOsDescription())
     if sys.platform == 'darwin':
         info.append("Mac OSX: %s" % platform.mac_ver()[0])
@@ -112,15 +112,23 @@ def EnvironmentInfo():
     info.append("#---- End System Information ----#")
     info.append("#---- Runtime Variables ----#")
     from profiler import Profile
+    ftypes = list()
     for key, val in Profile().iteritems():
         # Exclude "private" information
-        if key.startswith('FILE') or key == 'MYPROFILE':
+        if key == 'MYPROFILE' or key.startswith('FILE'):
             continue
+        elif key == 'LAST_SESSION' or key == 'FHIST':
+            for fname in val:
+                if u'.' in fname:
+                    ext = fname.split('.')[-1]
+                    if ext not in ftypes:
+                        ftypes.append(ext)
         else:
-            info.append("%s=%s" % (key, str(val)))
+            info.append(u"%s=%s" % (key, unicode(val)))
+    info.append(u"FTYPES=%s" % unicode(ftypes))
     info.append("#---- End Runtime Variables ----#")
 
-    return "\n".join(info)
+    return u"\n".join(info)
 
 def ExceptionHook(exctype, value, trace):
     """Handler for all unhandled exceptions
@@ -132,7 +140,10 @@ def ExceptionHook(exctype, value, trace):
     ftrace = FormatTrace(exctype, value, trace)
     # Ensure that error gets raised to console as well
     print ftrace
-    ErrorDialog(ftrace)
+
+    # Prevent multiple reporter dialogs from opening at once
+    if not REPORTER_ACTIVE and not ABORT:
+        ErrorDialog(ftrace)
 
 def FormatTrace(etype, value, trace):
     """Formats the given traceback
@@ -209,10 +220,12 @@ class ErrorReporter(object):
         """
         if len(self._sessionerr):
             return self._sessionerr[-1]
-
+        
 #-----------------------------------------------------------------------------#
 
 ID_SEND = wx.NewId()
+ABORT = False
+REPORTER_ACTIVE = False
 class ErrorDialog(wx.Dialog):
     """Dialog for showing and and notifying Editra.org should the
     user choose so.
@@ -223,6 +236,7 @@ class ErrorDialog(wx.Dialog):
         @param message: Error message to display
 
         """
+        REPORTER_ACTIVE = True
         wx.Dialog.__init__(self, None, title="Error/Crash Reporter", 
                            style=wx.DEFAULT_DIALOG_STYLE)
         
@@ -261,6 +275,7 @@ class ErrorDialog(wx.Dialog):
         t_lbl = wx.StaticText(self, label=_("Error Traceback:"))
         tctrl = wx.TextCtrl(self, value=self.err_msg, style=wx.TE_MULTILINE | 
                                                             wx.TE_READONLY)
+        abort_b = wx.Button(self, wx.ID_ABORT, _("Abort"))
         send_b = wx.Button(self, ID_SEND, _("Report Error"))
         send_b.SetDefault()
         close_b = wx.Button(self, wx.ID_CLOSE)
@@ -270,9 +285,9 @@ class ErrorDialog(wx.Dialog):
         sizer.AddMany([(icon, (1, 1)), (mainmsg, (1, 2), (1, 2)), 
                        ((2, 2), (3, 0)), (t_lbl, (3, 1), (1, 2)),
                        (tctrl, (4, 1), (8, 5), wx.EXPAND), ((5, 5), (4, 6)),
-                       ((2, 2), (12, 0)), 
-                       (send_b, (13, 3), (1, 1), wx.ALIGN_RIGHT),
-                       ((3, 3), (13, 4)),
+                       ((2, 2), (12, 0)),
+                       (abort_b, (13, 1), (1, 1), wx.ALIGN_LEFT),
+                       (send_b, (13, 3), (1, 2), wx.ALIGN_RIGHT),
                        (close_b, (13, 5), (1, 1), wx.ALIGN_RIGHT),
                        ((2, 2), (14, 0))])
         self.SetSizer(sizer)
@@ -289,11 +304,18 @@ class ErrorDialog(wx.Dialog):
         if e_id == wx.ID_CLOSE:
             self.Close()
         elif e_id == ID_SEND:
-            msg = "mailto:%s?subject=Error Report&body=%s"
-            addr = "bugs@%s" % (ed_glob.home_page.lstrip("http://"))
+            msg = u"mailto:%s?subject=Error Report&body=%s"
+            addr = u"bugs@%s" % (ed_glob.HOME_PAGE.lstrip("http://"))
             msg = msg % (addr, self.err_msg)
+            msg = msg.replace(u"'", u'')
             webbrowser.open(msg)
             self.Close()
+        elif e_id == wx.ID_ABORT:
+            ABORT = True
+            wx.CallLater(500, wx.GetApp().OnExit, 
+                         wx.MenuEvent(wx.wxEVT_MENU_OPEN, ed_glob.ID_EXIT),
+                         True)
+            self.Close()
         else:
             evt.Skip()
 
@@ -302,6 +324,6 @@ class ErrorDialog(wx.Dialog):
         @param evt: Event that called this handler
 
         """
+        REPORTER_ACTIVE = False
         self.Destroy()
         evt.Skip()
-
