@@ -36,18 +36,18 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 398 2007-08-31 11:03:55Z CodyPrecord $"
-__revision__ = "$Revision: 398 $"
+__svnid__ = "$Id: ed_glob.py 525 2007-09-26 07:50:18Z CodyPrecord $"
+__revision__ = "$Revision: 525 $"
 
-__all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'version', 'prog_name',
-            'ID_NEW', 'ID_OPEN', 'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 
-            'ID_SAVEAS', 'ID_SAVEALL', 'ID_SAVE_PROFILE', 'ID_LOAD_PROFILE', 
-            'ID_PRINT', 'ID_PRINT_PRE', 'ID_PRINT_SU', 'ID_EXIT', 'ID_UNDO', 
-            'ID_REDO', 'ID_CUT', 'ID_COPY', 'ID_PASTE', 'ID_SELECTALL', 
-            'ID_ADD_BM', 'ID_DEL_BM',  'ID_DEL_ALL_BM', 'ID_LINE_AFTER', 
-            'ID_LINE_BEFORE', 'ID_CUT_LINE', 'ID_COPY_LINE', 'ID_JOIN_LINES', 
-            'ID_TRANSPOSE', 'ID_FIND', 'ID_FIND_REPLACE', 'ID_QUICK_FIND', 
-            'ID_PREF', 'ID_ZOOM_OUT', 'home_page', 'contact_mail',
+__all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'VERSION', 'PROG_NAME',
+            'ID_NEW', 'ID_OPEN', 'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE',
+            'ID_SAVEAS', 'ID_SAVEALL', 'ID_SAVE_PROFILE', 'ID_LOAD_PROFILE',
+            'ID_PRINT', 'ID_PRINT_PRE', 'ID_PRINT_SU', 'ID_EXIT', 'ID_UNDO',
+            'ID_REDO', 'ID_CUT', 'ID_COPY', 'ID_PASTE', 'ID_SELECTALL',
+            'ID_ADD_BM', 'ID_DEL_BM',  'ID_DEL_ALL_BM', 'ID_LINE_AFTER',
+            'ID_LINE_BEFORE', 'ID_CUT_LINE', 'ID_COPY_LINE', 'ID_JOIN_LINES',
+            'ID_TRANSPOSE', 'ID_FIND', 'ID_FIND_REPLACE', 'ID_QUICK_FIND',
+            'ID_PREF', 'ID_ZOOM_OUT', 'HOME_PAGE', 'CONTACT_MAIL',
             'ID_ZOOM_IN', 'ID_ZOOM_NORMAL', 'ID_SHOW_EDGE', 'ID_SHOW_EOL',
             'ID_SHOW_LN', 'ID_SHOW_WS', 'ID_PERSPECTIVES', 'ID_INDENT_GUIDES', 
             'ID_VIEW_TOOL', 'ID_GOTO_LINE', 'ID_NEXT_MARK', 'ID_PRE_MARK', 
@@ -58,15 +58,16 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'SB_ROWCOL', 'version', 'prog_name',
             'ID_SYNTAX', 'ID_FOLDING', 'ID_BRACKETHL', 'ID_LEXER', 
             'ID_KWHELPER', 'ID_PLUGMGR', 'ID_STYLE_EDIT', 'ID_MACRO_START', 
             'ID_MACRO_STOP', 'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 
-            'ID_CONTACT', 'ID_COMMAND_BAR' 
+            'ID_CONTACT', 'ID_COMMAND_BAR', 'ID_DOCUMENTATION', 'ID_COMMAND',
+            'ID_CLOSE_WINDOW' 
 ]
 
 #---- Project Info ----#
-Author = __Author__  = u'Cody Precord'
-version = __version__ = u'0.1.78'
-prog_name = u'Editra'
-home_page = u"http://editra.org"
-contact_mail = u"staff@editra.org"
+AUTHOR = u'Cody Precord'
+VERSION = u'0.2.0'
+PROG_NAME = u'Editra'
+HOME_PAGE = u"http://editra.org"
+CONTACT_MAIL = u"staff@editra.org"
 #---- End Project Info ----#
 
 #---- Imported Libs/Objects ----#
@@ -80,7 +81,6 @@ CONFIG = {
           'PIXMAPS_DIR' : "",   # Graphics Directory
           'PLUGIN_DIR'  : "",   # User Plugin Dir
           'SYSPIX_DIR'  : "",   # Editras non user graphics
-          'MIME_DIR'    : "",   # MIME type graphics
           'THEME_DIR'   : "",   # Theme Directory
           'LANG_DIR'    : "",   # Locale Data Directory
           'SYS_PLUGIN_DIR' : "", # Editra base plugin dir
@@ -93,10 +93,12 @@ DEBUG = False
 #---- Object ID's ----#
 # File Menu IDs
 ID_NEW           = wx.ID_NEW
+ID_NEW_WINDOW    = wx.NewId()
 ID_OPEN          = wx.ID_OPEN
 ID_FHIST         = wx.NewId()
 ID_CLOSE         = wx.ID_CLOSE
 ID_CLOSEALL      = wx.ID_CLOSE_ALL
+ID_CLOSE_WINDOW  = wx.NewId()
 ID_SAVE          = wx.ID_SAVE
 ID_SAVEAS        = wx.ID_SAVEAS
 ID_SAVEALL       = wx.NewId()
@@ -202,6 +204,7 @@ ID_BRACKETHL     = wx.NewId()
 ID_LEXER         = wx.NewId()
 
 # Tool Menu IDs
+ID_COMMAND       = wx.NewId()
 ID_KWHELPER      = wx.NewId()
 ID_PLUGMGR       = wx.NewId()
 ID_STYLE_EDIT    = wx.ID_EDIT
@@ -216,32 +219,31 @@ ID_RTF_GEN       = wx.NewId()
 # Help Menu IDs
 ID_ABOUT         = wx.ID_ABOUT
 ID_HOMEPAGE      = wx.ID_HOME
+ID_DOCUMENTATION = wx.NewId()
 ID_CONTACT       = wx.NewId()
 
 # Misc IDs
 ID_APP_SPLASH        = wx.NewId()
-ID_BIN_FILE          = wx.NewId()
+ID_BIN_FILE          = ID_COMMAND
 ID_CDROM             = wx.NewId()
 ID_COMMAND_LINE_OPEN = wx.NewId()
 ID_COMMAND_BAR       = wx.NewId()
 ID_COMPUTER          = wx.NewId()
 ID_DELETE            = wx.NewId()
+ID_DOCPROP           = wx.NewId()
+ID_DOWN              = wx.ID_DOWN
 ID_DOWNLOAD_DLG      = wx.NewId()
 ID_FILE              = wx.ID_FILE
 ID_FLOPPY            = wx.NewId()
 ID_FOLDER            = wx.NewId()
 ID_HARDDISK          = wx.NewId()
-ID_PLUGIN_CFG        = wx.NewId()
-ID_PLUGIN_DL         = wx.NewId()
-ID_PLUGIN_INST       = wx.NewId()
+ID_PACKAGE           = wx.NewId()
 ID_REPORTER          = wx.NewId()
+ID_THEME             = wx.NewId()
 ID_USB               = wx.NewId()
-ID_PREF_ADVANCED     = wx.NewId()
-ID_PREF_APPEARANCE   = wx.NewId()
-ID_PREF_DOCUMENT     = wx.NewId()
-ID_PREF_GENERAL      = wx.NewId()
-ID_PREF_UPDATE       = wx.NewId()
+ID_UP                = wx.ID_UP
 ID_VI_MODE           = wx.NewId()
+ID_WEB               = wx.NewId()
 
 # Statusbar IDs
 SB_INFO          = 0
@@ -286,6 +288,7 @@ ID_2_PROF = {
              ID_PREF_ICONSZ       : 'ICON_SZ',
              ID_PREF_MODE         : 'MODE',
              ID_PRINT_MODE        : 'PRINT_MODE',
+             ID_NEW_WINDOW        : 'OPEN_NW',
              ID_VI_MODE           : 'VI_EMU'
 }
 
