@@ -50,8 +50,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 383 2007-08-26 12:19:16Z CodyPrecord $"
-__revision__ = "$Revision: 383 $"
+__svnid__ = "$Id: ed_main.py 548 2007-09-27 12:43:17Z CodyPrecord $"
+__revision__ = "$Revision: 548 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -89,11 +89,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
     """
     def __init__(self, parent, id_, wsize, title):
         """Initialiaze the Frame and Event Handlers.
-        @note: Automatically calls Show at the end of __init__
+        @
 
         """
         wx.Frame.__init__(self, parent, id_, title, size=wsize,
-                          style=wx.DEFAULT_FRAME_STYLE)
+                          style=wx.DEFAULT_FRAME_STYLE | \
+                                wx.NO_FULL_REPAINT_ON_RESIZE)
 
         self._mgr = wx.aui.AuiManager(flags=wx.aui.AUI_MGR_DEFAULT | \
                                       wx.aui.AUI_MGR_TRANSPARENT_DRAG | \
@@ -104,7 +105,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         self.SetTitle()
         self.LOG = wx.GetApp().GetLog()
-  
+        self._handlers = dict()
+        self._handlers['menu'] = list()
+        self._handlers['ui'] = list()
+
         # Try and set an app icon 
         util.SetWindowIcon(self)
 
@@ -121,7 +125,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         #---- Toolbar ----#
         self.toolbar = None
 
-        #---- Notebook to hold editor windows ----#
+        #---- Status bar on bottom of window ----#
+        self.CreateStatusBar(3, style = wx.ST_SIZEGRIP | wx.ST_DOTS_MIDDLE)
+        self.SetStatusWidths([-1, 120, 155])
+        #---- End Statusbar Setup ----#
+
+        #---- Notebook that contains the editting buffers ----#
         self.edit_pane = wx.Panel(self, wx.ID_ANY)
         self.nb = ed_pages.EdPages(self.edit_pane, wx.ID_ANY)
         self.edit_pane.nb = self.nb
@@ -141,11 +150,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self._cmdbar = ed_cmdbar.CommandBar(self.edit_pane, ID_COMMAND_BAR)
         self._cmdbar.Hide()
 
-        #---- Status bar on bottom of window ----#
-        self.CreateStatusBar(3, style = wx.ST_SIZEGRIP | wx.ST_DOTS_MIDDLE)
-        self.SetStatusWidths([-1, 120, 155])
-        #---- End Statusbar Setup ----#
-
         #---- Create a toolbar ----#
         if _PGET('TOOLBAR'):
             self.toolbar = ed_toolbar.EdToolBar(self, wx.ID_ANY)
@@ -169,6 +173,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self.editmenu = menbar.GetMenuByName("edit")
         self.viewmenu = menbar.GetMenuByName("view")
         self.vieweditmenu = menbar.GetMenuByName("viewedit")
+        # Todo this should not be hard coded
         self.viewmenu.InsertMenu(5, ID_PERSPECTIVES, _("Perspectives"), 
                                  self.GetPerspectiveControls())
         self.formatmenu = menbar.GetMenuByName("format")
@@ -193,7 +198,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
         #---- Actions to take on menu events ----#
         self.Bind(wx.EVT_MENU_OPEN, self.UpdateMenu)
-        self.BindLangMenu()
         if wx.Platform == '__WXGTK__':
             self.Bind(wx.EVT_MENU_HIGHLIGHT, \
                       self.OnMenuHighlight, id=ID_LEXER)
@@ -201,50 +205,61 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                       self.OnMenuHighlight, id=ID_EOL_MODE)
 
         # File Menu Events
-        self.Bind(wx.EVT_MENU, self.OnNew, id=ID_NEW)
-        self.Bind(wx.EVT_MENU, self.OnOpen, id=ID_OPEN)
-        self.Bind(wx.EVT_MENU, self.OnClosePage, id=ID_CLOSE)
-        self.Bind(wx.EVT_MENU, self.OnClosePage, id=ID_CLOSEALL)
-        self.Bind(wx.EVT_MENU, self.OnSave, id=ID_SAVE)
-        self.Bind(wx.EVT_MENU, self.OnSaveAs, id=ID_SAVEAS)
-        self.Bind(wx.EVT_MENU, self.OnSave, id=ID_SAVEALL)
-        self.Bind(wx.EVT_MENU, self.OnSaveProfile, id=ID_SAVE_PROFILE)
-        self.Bind(wx.EVT_MENU, self.OnLoadProfile, id=ID_LOAD_PROFILE)
-        self.Bind(wx.EVT_MENU, self.OnPrint)
-        self.Bind(wx.EVT_MENU, self.OnExit, id=ID_EXIT)
+        self._handlers['menu'].extend([(ID_NEW, self.OnNew),
+                                       (ID_OPEN, self.OnOpen),
+                                       (ID_CLOSE, self.OnClosePage),
+                                       (ID_CLOSE_WINDOW, self.OnClose),
+                                       (ID_CLOSEALL, self.OnClosePage),
+                                       (ID_SAVE, self.OnSave),
+                                       (ID_SAVEAS, self.OnSaveAs),
+                                       (ID_SAVEALL, self.OnSave),
+                                       (ID_SAVE_PROFILE, self.OnSaveProfile),
+                                       (ID_LOAD_PROFILE, self.OnLoadProfile),
+                                       (ID_EXIT, wx.GetApp().OnExit),
+                                       (ID_PRINT, self.OnPrint),
+                                       (ID_PRINT_PRE, self.OnPrint),
+                                       (ID_PRINT_SU, self.OnPrint)])
+
         self.Bind(wx.EVT_MENU_RANGE, self.OnFileHistory, 
                   id=wx.ID_FILE1, id2=wx.ID_FILE9)
 
         # Edit Menu Events
+        self._handlers['menu'].extend([(ID_FIND, self.nb.FindService.OnShowFindDlg),
+                                       (ID_FIND_REPLACE, self.nb.FindService.OnShowFindDlg),
+                                       (ID_QUICK_FIND, self.OnCommandBar),
+                                       (ID_PREF, self.OnPreferences)])
         self.Bind(wx.EVT_MENU, self.DispatchToControl)
-        self.Bind(wx.EVT_MENU, self.nb.FindService.OnShowFindDlg, id=ID_FIND)
-        self.Bind(wx.EVT_MENU, self.nb.FindService.OnShowFindDlg, 
-                  id=ID_FIND_REPLACE)
-        self.Bind(wx.EVT_MENU, self.OnQuickFind, id=ID_QUICK_FIND)
-        self.Bind(wx.EVT_MENU, self.OnPreferences, id=ID_PREF)
-
+        
         # View Menu Events
-        self.Bind(wx.EVT_MENU, self.OnGoto, id=ID_GOTO_LINE)
-        self.Bind(wx.EVT_MENU, self.OnViewTb, id=ID_VIEW_TOOL)
-
+        self._handlers['menu'].extend([(ID_GOTO_LINE, self.OnCommandBar),
+                                       (ID_VIEW_TOOL, self.OnViewTb)])
+        
         # Format Menu Events
-        self.Bind(wx.EVT_MENU, self.OnFont, id=ID_FONT)
+        self._handlers['menu'].append((ID_FONT, self.OnFont))
 
         # Tool Menu
-        self.Bind(wx.EVT_MENU, self.OnStyleEdit, id=ID_STYLE_EDIT)
-        self.Bind(wx.EVT_MENU, self.OnPluginMgr, id=ID_PLUGMGR)
+        self._handlers['menu'].extend([(ID_COMMAND, self.OnCommandBar),
+                                       (ID_STYLE_EDIT, self.OnStyleEdit),
+                                       (ID_PLUGMGR, self.OnPluginMgr)])
+
+        for l_id in syntax.SyntaxIds():
+            self._handlers['menu'].append((l_id, self.DispatchToControl))
+
         self.Bind(wx.EVT_MENU, self.OnGenerate)
 
         # Help Menu Events
-        self.Bind(wx.EVT_MENU, self.OnAbout, id=ID_ABOUT)
-        self.Bind(wx.EVT_MENU, self.OnHelp, id=ID_HOMEPAGE)
-        self.Bind(wx.EVT_MENU, self.OnHelp, id=ID_CONTACT)
+        self._handlers['menu'].extend([(ID_ABOUT, self.OnAbout),
+                                       (ID_HOMEPAGE, self.OnHelp),
+                                       (ID_DOCUMENTATION, self.OnHelp),
+                                       (ID_CONTACT, self.OnHelp)])
 
         #---- End Menu Setup ----#
 
         #---- Actions to Take on other Events ----#
         # Frame
-        self.Bind(wx.EVT_CLOSE, self.OnExit)
+        self.Bind(wx.EVT_ACTIVATE, self.OnActivate)
+        self.Bind(wx.EVT_CLOSE, self.OnClose)
+        self.Bind(ed_event.EVT_STATUS, self.OnStatus)
 
         # Find Dialog
         self.Bind(wx.EVT_FIND, self.nb.FindService.OnFind)
@@ -272,31 +287,66 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         plgmgr = wx.GetApp().GetPluginManager()
         addons = MainWindowAddOn(plgmgr)
         addons.Init(self)
+        self._handlers['menu'].extend(addons.GetEventHandlers())
+        self._handlers['ui'].extend(addons.GetEventHandlers(ui=True))
         self._shelf = iface.Shelf(plgmgr)
         self._shelf.Init(self)
         self.LOG("[main][info] Loading Generator plugins")
         self._generator = generator.Generator(plgmgr)
         self._generator.InstallMenu(self.toolsmenu)
 
-        # Load Session Data
-        if _PGET('SAVE_SESSION', 'bool', False):
+        # Load Session Data (only on first instance)
+        if _PGET('SAVE_SESSION', 'bool', False) and \
+           not len(wx.GetApp().GetMainWindows()):
             self.nb.LoadSessionFiles()
 
         # Set Perspective
         self.SetPerspective(_PGET('DEFAULT_VIEW'))
         self._mgr.Update()
-        self.Show(True)
 
     __name__ = u"MainWindow"
 
     ### End Private Member Functions/Variables ###
 
     ### Begin Public Function Definitions ###
+    def OnActivate(self, evt):
+        """Activation Event Handler
+        @param evt: event that called this handler
+        @type evt: wx.ActivateEvent
+
+        """
+        app = wx.GetApp()
+        if evt.GetActive():
+            for handler in self._handlers['menu']:
+                app.AddHandlerForID(*handler)
+
+            for handler in self._handlers['ui']:
+                app.AddUIHandlerForID(*handler)
+        else:
+            for handler in self._handlers['menu']:
+                app.RemoveHandlerForID(handler[0])
+
+            for handler in self._handlers['ui']:
+                app.RemoveUIHandlerForID(handler[0])
+        evt.Skip()
+
+    def AddFileToHistory(self, fname):
+        """Add a file to the windows file history as well as any
+        other open windows history.
+        @param fname: name of file to add
+        @todo: change the file history to a centrally manaaged object that
+               all windows pull from to avoid this quick solution.
+
+        """
+        for win in wx.GetApp().GetMainWindows():
+            if hasattr(win, 'filehistory'):
+                win.filehistory.AddFileToHistory(fname)
+        
     def DoOpen(self, evt, fname=u''):
         """ Do the work of opening a file and placing it
         in a new notebook page.
-        @param fname: can be optionally specified to open
-                      a file without opening a FileDialog
+        @keyword fname: can be optionally specified to open
+                        a file without opening a FileDialog
         @type fname: string
 
         """
@@ -316,14 +366,18 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 result = dlg.GetReturnCode()
 
             _PSET('FFILTER', dlg.GetFilterIndex())
+            o_win = _PGET('OPEN_NW', default=False)
             if result != wx.ID_CANCEL:
                 for path in paths:
-                    dirname = util.GetPathName(path)
-                    filename = util.GetFileName(path)
-                    self.nb.OpenPage(dirname, filename)		   
-                    self.SetTitle("%s - file://%s/%s" % \
-                                  (filename, dirname, filename))
-                    self.nb.GoCurrentPage()
+                    if o_win:
+                        wx.GetApp().OpenNewWindow(path)
+                    else:
+                        dirname = util.GetPathName(path)
+                        filename = util.GetFileName(path)
+                        self.nb.OpenPage(dirname, filename)		   
+                        self.SetTitle("%s - file://%s/%s" % \
+                                      (filename, dirname, filename))
+                        self.nb.GoCurrentPage()
             else:
                 pass
         else:
@@ -352,19 +406,19 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @return: None
 
         """
-        file_key = "FILE"
-        keys = range(size - 1)
-        keys.reverse()
-        for i in keys:
-            key = file_key + str(i)
-            path = _PGET(key, "str")
-            if isinstance(path, basestring) and path != wx.EmptyString:
-                self.filehistory.AddFileToHistory(path)
-            else:
-                pass
+        try:
+            hist_list = _PGET('FHIST', default=list())
+            if len(hist_list) > size:
+                hist_list = hist_list[:size]
+
+            for fname in hist_list:
+                if isinstance(fname, basestring) and fname:
+                    self.filehistory.AddFileToHistory(fname)
+        except UnicodeEncodeError, msg:
+            self.LOG("[main][err] Filehistory load failed: %s" % str(msg))
 
     def OnNew(self, evt):
-        """Star a New File
+        """Star a New File in a new tab
         @param evt: Event fired that called this handler
         @type evt: wxMenuEvent
 
@@ -386,7 +440,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             self.DoOpen(evt)
             self.UpdateToolBar()
         else:
-            evt.SkipId()
+            evt.Skip()
 
     def OnFileHistory(self, evt):
         """Open a File from the File History
@@ -466,7 +520,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                 ret_val = self.OnSaveAs(ID_SAVEAS, ctrl[0], ctrl[1])
                 if ret_val:
                     fpath = os.path.join(ctrl[1].dirname, ctrl[1].filename)
-                    self.filehistory.AddFileToHistory(fpath)
+                    self.AddFileToHistory(fpath)
         self.UpdateToolBar()
 
     def OnSaveAs(self, evt, title=u'', page=None):
@@ -556,6 +610,15 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             evt.Skip()
 
+    def OnStatus(self, evt):
+        """Update status text with messages from other controls
+        @param evt: event that called this handler
+
+        """
+        msg = evt.GetMessage()
+        if msg and self.GetStatusBar():
+            self.PushStatusText(msg, evt.GetSection())
+
     def OnPrint(self, evt):
         """Handles sending the current document to the printer,
         showing print previews, and opening the printer settings
@@ -576,19 +639,27 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             evt.Skip()
 
-    def OnExit(self, evt):
+    def Close(self, force=False):
+        """Close the window
+        @param force: force the closer by vetoing the event handler
+
+        """
+        if force:
+            return wx.Frame.Close(self, True)
+        else:
+            result = self.OnClose()
+            return not result
+
+    def OnClose(self, evt=None):
         """Close this frame and unregister it from the applications
         mainloop.
         @note: Closing the frame will write out all session data to the
                users configuration directory.
-        @param evt: Event fired that called this handler
+        @keyword evt: Event fired that called this handler
         @type evt: wxMenuEvent
+        @return: None on destroy, or True on cancel
 
         """
-        # This event is bound at two location need to unbind it to avoid fireing
-        # the event again
-        self.Unbind(wx.EVT_CLOSE)
-
         # Cleanup Controls
         controls = self.nb.GetPageCount()
         _PSET('LAST_SESSION', self.nb.GetFileNames())
@@ -597,7 +668,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         self._exiting = True
         while controls:
             if controls <= 0:
-                self.Close(True)
+                self.Close(True) # Force exit since there is a problem
 
             self.LOG("[main_evt] [exit] Requesting Page Close")
             result = self.nb.ClosePage()
@@ -612,8 +683,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             else:
                 # Rebind the event
                 self._exiting = False
-                self.Bind(wx.EVT_CLOSE, self.OnExit)
-                return
+                return True
         except UnboundLocalError:
             self.LOG("[main][exit][err] Trapped UnboundLocalError OnExit")
 
@@ -686,19 +756,6 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
     #---- End Edit Menu Functions ----#
 
     #---- View Menu Functions ----#
-    def OnGoto(self, evt):
-        """Shows the Goto Line control
-        @param evt: Event fired that called this handler
-        @type evt: wxMenuEvent
-
-        """
-        e_id = evt.GetId()
-        if e_id == ID_GOTO_LINE:
-            self._cmdbar.Show(ed_cmdbar.ID_LINE_CTRL)
-            self.sizer.Layout()
-        else:
-            evt.Skip()
-
     def OnViewTb(self, evt):
         """Toggles visibility of toolbar
         @note: On OSX there is a frame button for hidding the toolbar
@@ -716,6 +773,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             else:
                 self.toolbar = ed_toolbar.EdToolBar(self, wx.ID_ANY)
                 self.SetToolBar(self.toolbar)
+                self.SendSizeEvent()
+                self.RefreshRect(self.GetRect())
+                self.Update()
+                self.Refresh()
                 _PSET('TOOLBAR', True)
                 self.UpdateToolBar()
         else:
@@ -779,7 +840,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             if win is not None:
                 win.Raise()
                 return
-            dlg = plugdlg.PluginDialog(self, wx.ID_ANY, prog_name + " " \
+            dlg = plugdlg.PluginDialog(self, wx.ID_ANY, PROG_NAME + " " \
                                         + _("Plugin Manager"), \
                                         size=wx.Size(500, 350))
             dlg.CenterOnParent()
@@ -817,7 +878,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             year = time.localtime()
             desc = ["Editra is a programmers text editor.",
                     "Written in 100%% Python.",
-                    "Homepage: " + home_page + "\n",
+                    "Homepage: " + HOME_PAGE + "\n",
                     "Platform Info: (python %s,%s)", 
                     "License: GPL v2 (see COPYING.txt for full license)"]
             desc = "\n".join(desc)
@@ -826,9 +887,9 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             platform[0] += (" " + wx.VERSION_STRING)
             wx_info = ", ".join(platform)
             info.SetCopyright("Copyright(C) 2005-%d Cody Precord" % year[0])
-            info.SetName(prog_name.title())
+            info.SetName(PROG_NAME.title())
             info.SetDescription(desc % (py_version, wx_info))
-            info.SetVersion(version)
+            info.SetVersion(VERSION)
             wx.AboutBox(info)
         else:
             evt.Skip()
@@ -842,9 +903,11 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         import webbrowser
         e_id = evt.GetId()
         if e_id == ID_HOMEPAGE:
-            webbrowser.open(home_page, 1)
+            webbrowser.open(HOME_PAGE, 1)
+        elif e_id == ID_DOCUMENTATION:
+            webbrowser.open_new_tab(HOME_PAGE + "/?page=doc")
         elif e_id == ID_CONTACT:
-            webbrowser.open(u'mailto:%s' % contact_mail)
+            webbrowser.open(u'mailto:%s' % CONTACT_MAIL)
         else:
             evt.Skip()
 
@@ -913,11 +976,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type evt: wx.KeyEvent(EVT_KEY_UP)
 
         """
-        line, column = self.nb.GetCurrentCtrl().GetPos(evt)
-        if line >= 0 and column >= 0:
-            self.SetStatusText(_("Line: %d  Column: %d") % \
-                               (line, column), SB_ROWCOL)
-            self.UpdateToolBar()
+        self.SetStatusText(_("Line: %d  Column: %d") % \
+                           self.nb.GetCurrentCtrl().GetPos(), SB_ROWCOL)
         evt.Skip()
 
     def OnMenuHighlight(self, evt):
@@ -935,26 +995,29 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         else:
             evt.Skip()
 
-    def BindLangMenu(self):
-        """Binds Language Menu Ids to event handler
-        @note: This menu is dynamically generated based on the 
-               available file types and lexer configurations. 
-               
-        """
-        for l_id in syntax.SyntaxIds():
-            self.Bind(wx.EVT_MENU, self.DispatchToControl, id=l_id)
-
-    def OnQuickFind(self, evt):
-        """Open the Commandbar in Search mode.
+    def OnCommandBar(self, evt):
+        """Open the Commandbar
         @param evt: Event fired that called this handler
         @type evt: wxMenuEvent
 
         """
-        if evt.GetId() == ID_QUICK_FIND:
+        e_id = evt.GetId()
+        if e_id == ID_QUICK_FIND:
             self._cmdbar.Show(ed_cmdbar.ID_SEARCH_CTRL)
-            self.sizer.Layout()
+        elif e_id == ID_GOTO_LINE:
+            self._cmdbar.Show(ed_cmdbar.ID_LINE_CTRL)
+        elif e_id == ID_COMMAND:
+            self._cmdbar.Show(ed_cmdbar.ID_CMD_CTRL)
         else:
             evt.Skip()
+        self.sizer.Layout()
+
+    def ShowCommandCtrl(self):
+        """Open the Commandbar in command mode.
+
+        """
+        self._cmdbar.Show(ed_cmdbar.ID_CMD_CTRL)
+        self.sizer.Layout()
 
     # Menu Helper Functions
     #TODO this is fairly stupid, write a more general solution
@@ -1082,7 +1145,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         @type title: string
 
         """
-        name = "%s v%s" % (prog_name, version)
+        name = "%s v%s" % (PROG_NAME, VERSION)
         if len(title):
             name = u' - ' + name
         wx.Frame.SetTitle(self, title + name)
@@ -1092,19 +1155,47 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 #-----------------------------------------------------------------------------#
 # Plugin interface's to the MainWindow
 class MainWindowI(plugin.Interface):
-    """Provides simple one method interface into adding extra
-    functionality to the main window. 
-    @note: The method in this interface called once at the end 
-           of the window's internationalization.
+    """The MainWindow Interface is intended as a simple general purpose
+    interface for adding functionality to the main window. It does little
+    managing of how object the implementing it is handled, most is left up to
+    the plugin. Some examples of plugins using this interface are the
+    FileBrowser and Calculator plugins.
 
     """
     def PlugIt(self, window):
-        """Do whatever is needed to integrate is plugin
-        into the editor.
+        """This method is called once and only once per window when it is 
+        created. It should typically be used to register menu entries, 
+        bind event handlers and other similar actions.
+
+        @param window: The parent window of the plugin
         @postcondition: The plugins controls are installed in the L{MainWindow}
 
         """
-        pass
+        raise NotImplementedError
+
+    def GetMenuHandlers(self):
+        """Get menu event handlers/id pairs. This function should return a
+        list of tuples containing menu ids and their handlers. The handlers
+        should be not be a member of this class but a member of the ui component
+        that they handler acts upon.
+        
+        
+        @return: list [(ID_FOO, foo.OnFoo), (ID_BAR, bar.OnBar)]
+
+        """
+        raise NotImplementedError
+
+    def GetUIHandlers(self):
+        """Get update ui event handlers/id pairs. This function should return a
+        list of tuples containing object ids and their handlers. The handlers
+        should be not be a member of this class but a member of the ui component
+        that they handler acts upon.
+        
+        
+        @return: list [(ID_FOO, foo.OnFoo), (ID_BAR, bar.OnBar)]
+
+        """
+        raise NotImplementedError
 
 class MainWindowAddOn(plugin.Plugin):
     """Plugin that Extends the L{MainWindowI}"""
@@ -1120,3 +1211,21 @@ class MainWindowAddOn(plugin.Plugin):
                 ob.PlugIt(window)
             except Exception, msg:
                 log("[main_addon][err] %s" % str(msg))
+
+    def GetEventHandlers(self, ui=False):
+        """Get Event handlers and Id's from all observers
+        @keyword ui: Get Update Ui handlers (default get menu handlers)
+        @return: list [(ID_FOO, foo.OnFoo), (ID_BAR, bar.OnBar)]
+
+        """
+        handlers = list()
+        for ob in self.observers:
+            try:
+                if ui:
+                    items = ob.GetUIHandlers()
+                else:
+                    items = ob.GetMenuHandlers()
+            except Exception, msg:
+                continue
+            handlers.extend(items)
+        return handlers
