@@ -34,8 +34,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_menu.py 361 2007-08-19 00:09:10Z CodyPrecord $"
-__revision__ = "$Revision: 361 $"
+__svnid__ = "$Id: ed_menu.py 541 2007-09-27 08:15:58Z CodyPrecord $"
+__revision__ = "$Revision: 541 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -234,10 +234,9 @@ class EdMenuBar(wx.MenuBar):
         self._toolsmenu = self.GenToolsMenu()
         self._helpmenu = self.GenHelpMenu()
 
-    # TODO these Gen functions should be broken up to the components
+    # TODO these Gen* functions should be broken up to the components
     #      that supply the functionality and inserted in the menus on
-    #      init when the editor loads an associated widget. But this
-    #      is the first step to get there.
+    #      init when the editor loads an associated widget. 
     def GenFileMenu(self):
         """Makes and attaches the file menu
         @return: the default file menu
@@ -245,8 +244,11 @@ class EdMenuBar(wx.MenuBar):
         """
         filemenu = ED_Menu()
         filehist = self._filehistorymenu
-        filemenu.Append(ed_glob.ID_NEW, _("New") + u"\tCtrl+N", 
-                        _("Start a New File"))
+        filemenu.Append(ed_glob.ID_NEW, _("New Tab") + u"\tCtrl+N", 
+                        _("Start a new file in a new tab"))
+        filemenu.Append(ed_glob.ID_NEW_WINDOW, _("New Window") + \
+                        "\tCtrl+Shift+N", _("Start a new file in a new window"))
+        filemenu.AppendSeparator()
         filemenu.Append(ed_glob.ID_OPEN, _("Open") + "\tCtrl+O", _("Open"))
         ## Setup File History in the File Menu
         filemenu.AppendMenu(ed_glob.ID_FHIST, _("Open Recent"), 
@@ -254,6 +256,9 @@ class EdMenuBar(wx.MenuBar):
         filemenu.AppendSeparator()
         filemenu.Append(ed_glob.ID_CLOSE, _("Close Page") + "\tCtrl+W", 
                         _("Close Current Page"))
+        filemenu.Append(ed_glob.ID_CLOSE_WINDOW, 
+                        _("Close Window") + "\tCtrl+Shift+W",
+                        _("Close the current window"))
         filemenu.Append(ed_glob.ID_CLOSEALL, _("Close All Pages"),
                         _("Close all open tabs"))
         filemenu.AppendSeparator()
@@ -270,7 +275,7 @@ class EdMenuBar(wx.MenuBar):
         pmenu.Append(ed_glob.ID_LOAD_PROFILE, _("Load Profile"), 
                      _("Load a Custom Profile"))
         filemenu.AppendSubMenu(pmenu, _("Profile"), 
-                               _("Load and save custom rofiles"))
+                               _("Load and save custom Profiles"))
         filemenu.AppendSeparator()
         filemenu.Append(ed_glob.ID_PRINT_SU, _("Page Setup") + "\tCtrl+Shift+P",
                         _("Configure Printer"))
@@ -462,6 +467,8 @@ class EdMenuBar(wx.MenuBar):
 
         """
         toolsmenu = ED_Menu()
+        toolsmenu.Append(ed_glob.ID_COMMAND, _("Editor Command") + u'\tCtrl+E',
+                         _("Goto command buffer"))
         toolsmenu.Append(ed_glob.ID_KWHELPER, _("Keyword Helper") + u'\tCtrl+K', 
                          _("Provides a Contextual Help Menu Listing Standard "
                            "Keywords/Functions"))
@@ -487,9 +494,11 @@ class EdMenuBar(wx.MenuBar):
         helpmenu.Append(ed_glob.ID_ABOUT, _("&About") + u"...", \
                         _("About") + u"...")
         helpmenu.Append(ed_glob.ID_HOMEPAGE, _("Project Homepage"), 
-                            _("Visit the project homepage %s") % ed_glob.home_page)
+                        _("Visit the project homepage %s") % ed_glob.HOME_PAGE)
+        helpmenu.Append(ed_glob.ID_DOCUMENTATION, _("Online Documentation"),
+                        _("Online project documentation and help guides"))
         helpmenu.Append(ed_glob.ID_CONTACT, _("Feedback"),
-                            _("Send me bug reports and suggestions"))
+                        _("Send me bug reports and suggestions"))
         self.Append(helpmenu, _("Help"))
         return helpmenu
 
