@@ -42,8 +42,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 369 2007-08-20 07:55:44Z CodyPrecord $"
-__revision__ = "$Revision: 369 $"
+__svnid__ = "$Id: ed_pages.py 529 2007-09-26 09:49:01Z CodyPrecord $"
+__revision__ = "$Revision: 529 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -53,14 +53,11 @@ import re
 import wx
 import ed_glob
 from profiler import Profile_Get, Profile_Set
-import ed_event
 import ed_stc
 import syntax.synglob as synglob
 import ed_search
 import util
 import doctools
-# import wx.lib.flatnotebook as FNB
-# Use local copy until newer release of wxpython
 from extern import flatnotebook as FNB
 
 #--------------------------------------------------------------------------#
@@ -69,7 +66,7 @@ from extern import flatnotebook as FNB
 _ = wx.GetTranslation
 #--------------------------------------------------------------------------#
 class EdPages(FNB.FlatNotebook):
-    """Editras Notebook
+    """Editras editor buffer botebook
     @todo: allow for tab styles to be configurable (maybe)
 
     """
@@ -84,7 +81,8 @@ class EdPages(FNB.FlatNotebook):
                                         FNB.FNB_X_ON_TAB | 
                                         FNB.FNB_SMART_TABS |
                                         FNB.FNB_BACKGROUND_GRADIENT |
-                                        FNB.FNB_DROPDOWN_TABS_LIST
+                                        FNB.FNB_DROPDOWN_TABS_LIST |
+                                        FNB.FNB_ALLOW_FOREIGN_DND
                             )
 
         # Notebook attributes
@@ -92,9 +90,9 @@ class EdPages(FNB.FlatNotebook):
         self.FindService = ed_search.TextFinder(self, self.GetCurrentCtrl)
         self.DocMgr = doctools.DocPositionMgr(ed_glob.CONFIG['CACHE_DIR'] + \
                                               util.GetPathChar() + u'positions')
-        self.pg_num = 0               # Track page numbers for ID creation
-        self.control = ed_stc.EDSTC   # Current Control page
-        self.frame = parent.GetParent() # MainWindow
+        self.pg_num = -1              # Track new pages (aka untitled docs)
+        self.control = None
+        self.frame = self.GetTopLevelParent() # MainWindow
         self._index = dict()          # image list index
 
         # Set Additional Style Parameters
@@ -113,7 +111,7 @@ class EdPages(FNB.FlatNotebook):
         self.Bind(FNB.EVT_FLATNOTEBOOK_PAGE_CHANGED, self.OnPageChanged)
         self.Bind(FNB.EVT_FLATNOTEBOOK_PAGE_CLOSING, self.OnPageClosing)
         self.Bind(FNB.EVT_FLATNOTEBOOK_PAGE_CLOSED, self.OnPageClosed)
-        self.Bind(ed_event.EVT_UPDATE_TEXT, self.OnUpdatePageText)
+        self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnUpdatePageText)
         self._pages.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
         self.Bind(wx.EVT_IDLE, self.OnIdle)
 
@@ -129,7 +127,6 @@ class EdPages(FNB.FlatNotebook):
         @param title: page title string
 
         """
-        self.pg_num += 1
         FNB.FlatNotebook.AddPage(self, control, title)
 
     def GetCurrentCtrl(self):
@@ -165,7 +162,8 @@ class EdPages(FNB.FlatNotebook):
         files = Profile_Get('LAST_SESSION')
         if files is not None:
             for file in files:
-                self.OpenPage(os.path.dirname(file), os.path.basename(file))
+                if os.path.exists(file):
+                    self.OpenPage(os.path.dirname(file), os.path.basename(file))
 
         if self.GetPageCount() == 0:
             self.NewPage()
@@ -175,7 +173,8 @@ class EdPages(FNB.FlatNotebook):
         @postcondition: a new page with an untitled document is opened
 
         """
-        self.control = ed_stc.EDSTC(self, self.pg_num)
+        self.pg_num += 1
+        self.control = ed_stc.EDSTC(self, wx.ID_ANY)
         self.LOG("[nb_evt] Page Creation ID: %d" % self.control.GetId())
         self.AddPage(self.control, u"Untitled - %d" % self.pg_num)
         self.SetPageImage(self.GetSelection(), str(self.control.GetLangId()))
@@ -224,12 +223,12 @@ class EdPages(FNB.FlatNotebook):
         if self.GetPageCount():
             if self.control.GetModify() or self.control.GetLength() or \
                self.control.filename != u'':
-                control = ed_stc.EDSTC(self, self.pg_num)
+                control = ed_stc.EDSTC(self, wx.ID_ANY)
                 control.Hide()
             else:
                 new_pg = False
         else:
-            control = ed_stc.EDSTC(self, self.pg_num)
+            control = ed_stc.EDSTC(self, wx.ID_ANY)
             control.Hide()
 
         # Open file and get contents
@@ -261,7 +260,7 @@ class EdPages(FNB.FlatNotebook):
         self.control.SetText(in_txt, enc)
         # Pass directory and file name info to control object to save reference
         self.control.dirname, self.control.filename = path, filename
-        self.frame.filehistory.AddFileToHistory(path2file)
+        self.frame.AddFileToHistory(path2file)
         self.control.modtime = util.GetFileModTime(path2file)
         if new_pg:
             self.AddPage(self.control, self.control.filename)
@@ -311,10 +310,9 @@ class EdPages(FNB.FlatNotebook):
 
         """
         txt = FNB.FlatNotebook.GetPageText(self, pg_num)
-        if txt[0] != u"*":
+        if not txt or txt[0] != u"*":
             return txt
-        else:
-            return txt[1:]
+        return txt[1:]
 
     def GetTextControls(self):
         """Gets all the currently opened text controls
@@ -402,8 +400,8 @@ class EdPages(FNB.FlatNotebook):
         @type evt: wx.IdleEvent
 
         """
-        if Profile_Get('CHECKMOD') and \
-           wx.GetApp().IsActive() and self.GetPageCount():
+        if wx.GetApp().IsActive() and \
+           Profile_Get('CHECKMOD') and self.GetPageCount():
             cfile = os.path.join(self.control.dirname, self.control.filename)
             lmod = util.GetFileModTime(cfile)
             if self.control.modtime and not lmod and not os.path.exists(cfile):
@@ -443,7 +441,16 @@ class EdPages(FNB.FlatNotebook):
                     result = mdlg.ShowModal()
                     mdlg.Destroy()
                     if result == wx.ID_YES:
-                        self.control.ReloadFile()
+                        ret, rmsg = self.control.ReloadFile()
+                        if not ret:
+                            mdlg = wx.MessageDialog(self.frame, 
+                                                    _("Failed to reload %s:\n"
+                                                      "Error: %s") % \
+                                                      (cfile, rmsg),
+                                                    _("Error"),
+                                                    wx.OK | wx.ICON_ERROR)
+                            mdlg.ShowModal()
+                            mdlg.Destroy()
                     else:
                         self.control.modtime = util.GetFileModTime(cfile)
                 wx.CallAfter(AskToReload, cfile)
@@ -485,6 +492,7 @@ class EdPages(FNB.FlatNotebook):
     def ChangePage(self, pgid):
         """Change the page and focus to the the given page id
         @param pgid: Page number to change to
+        @todo: generalize this to avoid expecting an edstc
 
         """
         window = self.GetPage(pgid) #returns current stc
@@ -492,7 +500,7 @@ class EdPages(FNB.FlatNotebook):
         self.control = window
 
         if self.control.filename == "":
-            self.control.filename = "Untitled - %d" % window.GetId()
+            self.control.filename = self.GetPageText(pgid)
 
         self.frame.SetTitle("%s - file://%s%s%s" % (self.control.filename,
                                                     self.control.dirname,
@@ -503,9 +511,6 @@ class EdPages(FNB.FlatNotebook):
         if matchstrn.match(self.control.filename):
             self.control.filename = ""
 
-        self.control.Bind(wx.EVT_KEY_UP, self.frame.OnKeyUp)
-        self.control.Bind(wx.EVT_LEFT_UP, self.frame.OnKeyUp)
-
     def OnPageChanged(self, evt):
         """Actions to do after a page change
         @param evt: event that called this handler
@@ -542,12 +547,6 @@ class EdPages(FNB.FlatNotebook):
 
         """
         self.LOG("[nb_evt] Closed Page: #%d" % self.GetSelection())
-        # wxMAC Bug? 
-        # Make sure tab area is refreshed mostly for when all pages have been
-        # closed to make sure that the last tab is removed from the view after
-        # deletion.
-        self.Update()
-        self.Refresh()
         evt.Skip()
     #---- End Event Handlers ----#
 
@@ -556,7 +555,7 @@ class EdPages(FNB.FlatNotebook):
         @postcondition: all pages in the notebook are closed
 
         """
-        for page in range(self.GetPageCount()):
+        for page in xrange(self.GetPageCount()):
             result = self.ClosePage()
             if result == wx.ID_CANCEL:
                 self.LOG("[nb][closeall] Canceled on page %d" % page)
@@ -587,8 +586,9 @@ class EdPages(FNB.FlatNotebook):
             self.GoCurrentPage()
 
         # TODO this causes some flashing
+        frame = self.GetTopLevelParent()
         if not self.GetPageCount() and \
-           not wx.GetApp().GetMainWindow().IsExiting():
+           hasattr(frame, 'IsExiting') and not frame.IsExiting():
             self.NewPage()
         return result
 
@@ -626,18 +626,19 @@ class EdPages(FNB.FlatNotebook):
     def OnUpdatePageText(self, evt):
         """Update the title text of the current page
         @param evt: event that called this handler
-        @type evt: ed_event.UpdateTextEvent
+        @type evt: stc.EVT_STC_MODIFY
+        @note: this method must complete its work very fast it gets
+               called everytime a character is entered or removed from
+               the document.
 
         """
         pg_num = self.GetSelection()
-        if isinstance(self.control, ed_stc.EDSTC):
-            title = self.control.filename
-            if title == wx.EmptyString:
-                title = self.GetPageText(pg_num)
-            if self.control.GetModify():
-                title = u"*" + title
+        title = self.GetPageText(pg_num)
+        if self.control.GetModify():
+            title = u"*" + title
+        if title != FNB.FlatNotebook.GetPageText(self, pg_num):
             wx.CallAfter(self.SetPageText, pg_num, title)
-            
+        
     def UpdateTextControls(self):
         """Updates all text controls to use any new settings that have
         been changed since initialization.
