@@ -45,8 +45,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 392 2007-08-30 17:38:53Z CodyPrecord $"
-__revision__ = "$Revision: 392 $"
+__svnid__ = "$Id: ed_stc.py 552 2007-09-28 08:18:37Z CodyPrecord $"
+__revision__ = "$Revision: 552 $"
 
 #-------------------------------------------------------------------------#
 # Dependencies
@@ -104,13 +104,13 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetModEventMask(wx.stc.STC_PERFORMED_UNDO | \
                              wx.stc.STC_PERFORMED_REDO | \
                              wx.stc.STC_MOD_DELETETEXT | \
-                             wx.stc.STC_MOD_INSERTTEXT | \
-                             wx.stc.STC_PERFORMED_USER)
+                             wx.stc.STC_MOD_INSERTTEXT)
 
         self.CmdKeyAssign(ord('-'), wx.stc.STC_SCMOD_CTRL, \
                           wx.stc.STC_CMD_ZOOMOUT)
         self.CmdKeyAssign(ord('+'), wx.stc.STC_SCMOD_CTRL | \
                           wx.stc.STC_SCMOD_SHIFT, wx.stc.STC_CMD_ZOOMIN)
+
         #---- Drop Target ----#
         if use_dt:
             self.SetDropTarget(util.DropTargetFT(self, None, parent.OnDrop))
@@ -174,14 +174,16 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         ### Folder Marker Styles
         self.DefineMarkers()
 
-        # Events
-        if self.brackethl:
-            self.Bind(wx.stc.EVT_STC_UPDATEUI, self.OnUpdateUI)
-        self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
+#         self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
         self.Bind(wx.stc.EVT_STC_MARGINCLICK, self.OnMarginClick)
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnModified)
         self.Bind(wx.EVT_CHAR, self.OnChar)
         self.Bind(wx.EVT_KEY_DOWN, self.OnKeyDown)
+
+        frame = self.GetTopLevelParent()
+        if hasattr(frame, 'OnKeyUp'):
+            self.Bind(wx.EVT_KEY_UP, self.GetTopLevelParent().OnKeyUp)
+            self.Bind(wx.EVT_LEFT_UP, self.GetTopLevelParent().OnKeyUp)
        #---- End Init ----#
 
     __name__ = u"EditraTextCtrl"
@@ -309,6 +311,15 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if mark != -1:
             self.GotoLine(mark)
 
+    def GetBookmarks(self):
+        """Gets a list of all lines containing bookmarks
+        @return: list of line numbers
+
+        """
+        marks = [mark for mark in xrange(self.GetLineCount()) 
+                          if self.MarkerGet(mark)]
+        return marks
+
     def Configure(self):
         """Configures the editors settings by using profile values
         @postcondition: all profile dependant attributes are configured
@@ -436,23 +447,13 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             mid = (fline + (self.GetLineCount() / 2))
         return mid
 
-    def GetPos(self, key):
+    def GetPos(self):
         """Update Line/Column information
-        @param key: KeyEvent object
+        @return: tuple (line, column)
 
         """
-        pos = self.GetCurrentPos()
-        line = self.GetCurrentLine()
-        column = self.GetColumn(pos)
-        if (self.old_pos != pos):
-            self.old_pos = pos
-            if self._use_autocomp and key.GetEventType() != wx.wxEVT_LEFT_UP:
-                key_code = key.GetKeyCode()
-                if key_code == wx.WXK_RETURN:
-                    self._autocomp_svc.UpdateNamespace(True)
-            return (line + 1, column)
-        else:
-            return (-1, -1)
+        self.old_pos = self.GetCurrentPos()
+        return (self.GetCurrentLine() + 1, self.GetColumn(self.old_pos))
 
     def GotoColumn(self, column):
         """Move caret to column of current line
@@ -467,6 +468,19 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             column = linelen
         self.GotoPos(lstart + column)
 
+    def GotoLine(self, line):
+        """Move caret to begining given line number
+        @param line: line to go to
+
+        """
+        if line > self.GetLineCount():
+            line = self.GetLineCount()
+        elif line < 0:
+            line = 0
+        else:
+            pass
+        wx.stc.StyledTextCtrl.GotoLine(self, line)
+
     def SetCurrentCol(self, column):
         """Set the current column position on the currently line
         extending the selection.
@@ -584,11 +598,20 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.SetViNormalMode(True)
             evt.Skip()
             return
-        if self._autoindent and k_code == wx.WXK_RETURN:
-            if self.GetSelectedText():
-                self.CmdKeyExecute(wx.stc.STC_CMD_NEWLINE)
-                return
-            self.AutoIndent()
+        elif k_code == wx.WXK_RETURN:
+
+            if self._autoindent:
+                if self.GetSelectedText():
+                    self.CmdKeyExecute(wx.stc.STC_CMD_NEWLINE)
+                    return
+                self.AutoIndent()
+            else:
+                evt.Skip()
+
+            if self._use_autocomp:
+                if self.CallTipActive():
+                    self.CallTipCancel()
+                self._autocomp_svc.UpdateNamespace(True)
         else:
             evt.Skip()
 
@@ -606,15 +629,14 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if self._vimode and self._vinormal:
             self._cmdcache = self._cmdcache + unichr(key_code)
             self.ViCmdDispatch()
-            return
-        if not self._use_autocomp:
+        elif not self._use_autocomp:
             evt.Skip()
-            return True
-        if key_code in self._autocomp_svc.GetAutoCompKeys():
+            return
+        elif key_code in self._autocomp_svc.GetAutoCompKeys():
             if self.AutoCompActive():
                 self.AutoCompCancel()
             command = self.GetCommandStr() + chr(key_code)
-            self.AddText(chr(key_code))
+            self.AddText(unichr(key_code))
             if self._use_autocomp:
                 self.ShowAutoCompOpt(command)
         elif key_code in self._autocomp_svc.GetCallTipKeys():
@@ -643,7 +665,6 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 lparm = evt.GetLParam()
             mac = (msg, evt.GetWParam(), lparm)
             self._macro.append(mac)
-            print mac
 #             if mac[0] != 2170:
 #                 self._macro.append(mac)
         else:
@@ -685,13 +706,15 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         col = self.GetColumn(curr_pos)
         cmd_lmt = list(self._autocomp_svc.GetAutoCompStops())
         for key in self._autocomp_svc.GetAutoCompKeys():
-            if chr(key) in cmd_lmt:
-                cmd_lmt.remove(chr(key))
+            kval = chr(key)
+            if kval in cmd_lmt:
+                cmd_lmt.remove(kval)
+
         while self.GetTextRange(start, curr_pos)[0] not in cmd_lmt \
               and col - (curr_pos - start) > 0:
             start -= 1
-        s_col = self.GetColumn(start)
-        if s_col != 0:
+
+        if self.GetColumn(start) != 0:
             start += 1
         cmd = self.GetTextRange(start, curr_pos)
         return cmd.strip()
@@ -742,9 +765,7 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @type evt: wx.stc.StyledTextEvent
 
         """
-        mevt = ed_event.UpdateTextEvent(ed_event.edEVT_UPDATE_TEXT, \
-                                        self.GetId())
-        wx.PostEvent(self.GetParent(), mevt)
+        wx.PostEvent(self.GetParent(), evt)
 
     def OnUpdateUI(self, evt):
         """Check for matching braces
@@ -1181,7 +1202,16 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             eline = 1
         lines = list()
         for line in xrange(sline, eline + 1):
-            lines.append(self.GetLine(line).strip())
+            if line != sline:
+                tmp = self.GetLine(line).strip()
+            else:
+                tmp = self.GetLine(line)
+                if not tmp.isspace():
+                    tmp = tmp.rstrip()
+                else:
+                    tmp = tmp.replace("\n", u'').replace("\r", u'')
+            if len(tmp):
+                lines.append(tmp)
         self.SetTargetStart(self.PositionFromLine(sline))
         self.SetTargetEnd(self.GetLineEndPosition(eline))
         self.ReplaceTarget(u' '.join(lines))
@@ -1236,15 +1266,17 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         self._vinormal = normal
         self._cmdcache = u''
-        mw = wx.GetApp().GetMainWindow()
+        mw = self.GetTopLevelParent()
         if normal:
             self.SetCaretWidth(10)
-            if mw:
-                mw.SetStatusText('NORMAL', ed_glob.SB_BUFF)
+            msg = 'NORMAL'
         else:
             self.SetCaretWidth(1)
-            if mw:
-                mw.SetStatusText('INSERT', ed_glob.SB_BUFF)
+            msg = 'INSERT'
+
+        evt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(), 
+                                   msg, ed_glob.SB_BUFF)
+        wx.PostEvent(self.GetTopLevelParent(), evt)
 
     def SetViewEdgeGuide(self, switch=None):
         """Toggles the visibility of the edge guide
@@ -1263,8 +1295,10 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.recording = True
-        wx.GetApp().GetMainWindow().SetStatusText(_("Recording Macro") + \
-                                                  u"...", ed_glob.SB_INFO)
+        evt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(),
+                                   _("Recording Macro") + u"...",
+                                   ed_glob.SB_INFO)
+        wx.PostEvent(self.GetTopLevelParent(), evt)
         wx.stc.StyledTextCtrl.StartRecord(self)
 
     def StopRecord(self):
@@ -1274,8 +1308,10 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         self.recording = False
         wx.stc.StyledTextCtrl.StopRecord(self)
-        wx.GetApp().GetMainWindow().SetStatusText(_("Recording Finished"), \
-                                                  ed_glob.SB_INFO)
+        evt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(),
+                                   _("Recording Finished"),
+                                   ed_glob.SB_INFO)
+        wx.PostEvent(self.GetTopLevelParent(), evt)
         self._BuildMacro()
 
     def TrimWhitespace(self):
@@ -1322,7 +1358,11 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             cmd = self._vilast
         cpos = self.GetCurrentPos()
         cline = self.LineFromPosition(cpos)
-        mw = wx.GetApp().GetMainWindow()
+        mw = self.GetTopLevelParent()
+        if u':' in cmd:
+            self._cmdcache = u''
+            mw.ShowCommandCtrl()
+
         # Single key commands
         if len(cmd) == 1 and (cmd in 'AHILmM0^$nia/?:'):
             if  cmd in u'A$': # Insert at EOL
@@ -1344,14 +1384,12 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     self.Bookmark(ed_glob.ID_ADD_BM)
             elif cmd == u'a': # insert mode after current pos
                 self.GotoPos(cpos + 1)
-            elif cmd in u'/?:':
+            elif cmd in u'/?':
                 if mw is not None:
-                    if cmd in u'/?':
-                        mid = ed_glob.ID_QUICK_FIND
-                    else:
-                        mid = ed_glob.ID_GOTO_LINE
-                    evt = wx.MenuEvent(wx.wxEVT_COMMAND_MENU_SELECTED, mid)
+                    evt = wx.MenuEvent(wx.wxEVT_COMMAND_MENU_SELECTED,
+                                       ed_glob.ID_QUICK_FIND)
                     wx.PostEvent(mw, evt)
+
             if cmd in u'aAiI':
                 self.SetViNormalMode(False)
 
@@ -1439,6 +1477,8 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 self.Cut()
             elif rcmd == u'J':
                 self.SetTargetStart(cpos)
+                if repeat == 1:
+                    repeat = 2
                 self.SetTargetEnd(self.PositionFromLine(cline + repeat - 1))
                 self.LinesJoin()
             elif rcmd == u'G':
@@ -1601,7 +1641,10 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         # Update status bar
         if mw and self._vinormal:
-            mw.SetStatusText('NORMAL\t%s' % self._cmdcache, ed_glob.SB_BUFF)
+            evt = ed_event.StatusEvent(ed_event.edEVT_STATUS, self.GetId(),
+                                       'NORMAL\t%s' % self._cmdcache,
+                                        ed_glob.SB_BUFF)
+            wx.PostEvent(self.GetTopLevelParent(), evt)
         
     def FoldingOnOff(self, switch=None):
         """Turn code folding on and off
@@ -1658,7 +1701,6 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.LOG("[stc_evt] Bracket Highlighting Turned Off")
             self.brackethl = False
             self.Unbind(wx.stc.EVT_STC_UPDATEUI)
-            self.Unbind(wx.stc.EVT_STC_UPDATEUI)
 
     def ToggleLineNumbers(self, switch=None):
         """Toggles the visibility of the line number margin
@@ -1803,6 +1845,7 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         cfile = os.path.join(self.dirname, self.filename)
         if os.path.exists(cfile):
+            bmarks = self.GetBookmarks()
             try:
                 self.BeginUndoAction()
                 cpos = self.GetCurrentPos()
@@ -1810,17 +1853,19 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                 self.SetText(reader.read())
                 reader.close()
                 self.modtime = util.GetFileModTime(cfile)
+                for mark in bmarks:
+                    self.MarkerAdd(mark, MARK_MARGIN)
                 self.EndUndoAction()
                 self.SetSavePoint()
-            except (OSError, IOError):
+            except (AttributeError, OSError, IOError), msg:
                 self.LOG("[stc][err] Failed to Reload %s" % cfile)
-                return False
+                return False, str(msg)
             else:
                 self.GotoPos(cpos)
-                return True
+                return True, ''
         else:
             self.LOG("[stc][err] %s does not exists, cannot reload it." % cfile)
-            return False
+            return False, "%s does not exist" % cfile
 
     def SaveFile(self, path):
         """Save buffers contents to disk
@@ -1852,7 +1897,7 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         if result:
             self.SetSavePoint()
             self.modtime = util.GetFileModTime(path)
-            self.OnModified(wx.ID_ANY)
+            self.OnModified(wx.stc.StyledTextEvent(wx.stc.wxEVT_STC_MODIFIED))
             self.filename = util.GetFileName(path)
             self.dirname = util.GetPathName(path)
         return result
@@ -2105,7 +2150,8 @@ class EDSTC(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @postcondtion: style scheme is set to specified style
 
         """
-        self.LoadStyleSheet(self.GetStyleSheet(spec_style))
+        if spec_style != self.style_set:
+            self.LoadStyleSheet(self.GetStyleSheet(spec_style), force=True)
         self.UpdateBaseStyles()
         self.SetSyntax(self.syntax_set)
         self.DefineMarkers()
