@@ -43,8 +43,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_style.py 387 2007-08-28 05:15:47Z CodyPrecord $"
-__revision__ = "$Revision: 387 $"
+__svnid__ = "$Id: ed_style.py 551 2007-09-28 07:58:06Z CodyPrecord $"
+__revision__ = "$Revision: 551 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -53,6 +53,7 @@ import re
 import wx
 import util
 from profiler import Profile_Get as _PGET
+from profiler import Profile_Set as _PSET
 
 # Globals
 STY_ATTRIBUTES     = u"face fore back size"
@@ -290,11 +291,9 @@ class StyleMgr(object):
     """Manages style definitions and provides them on request.
     Also provides functionality for loading custom style sheets and 
     modifying styles during run time.
-    @todo: possibly reimplement as a singleton to reduce the amout of duplicate
-           data that is stored for each control.
-    @todo: dont load style sheet for every newly created instance
 
     """
+    styles         = dict()
     FONT_PRIMARY   = u"primary"
     FONT_SECONDARY = u"secondary"
     FONT_SIZE      = u"size"
@@ -310,7 +309,6 @@ class StyleMgr(object):
         # Attributes
         self.fonts = self.GetFontDictionary()
         self.style_set = custom
-        self.styles = dict()
         self.LOG = wx.GetApp().GetLog()
 
         # Get the Style Set
@@ -331,7 +329,7 @@ class StyleMgr(object):
         def_dict = \
             {'brace_good' : StyleItem("#FFFFFF", "#0000FF,bold"),
              'brace_bad'  : StyleItem(back="#FF0000,bold"),
-             'calltip' : StyleItem("#404040", "#FFFFB8"),
+             'calltip'    : StyleItem("#404040", "#FFFFB8"),
              'ctrl_char'  : StyleItem(),
              'line_num'   : StyleItem(back="#C0C0C0", face="%(secondary)s", \
                                       size="%(size3)d"),
@@ -401,12 +399,14 @@ class StyleMgr(object):
         else:
             mfont = wx.Font(10, wx.FONTFAMILY_MODERN, wx.FONTSTYLE_NORMAL, 
                             wx.FONTWEIGHT_NORMAL)
+            _PSET('FONT1', mfont, 'font')
         primary = mfont.GetFaceName()
 
         font = _PGET('FONT2', 'font', None)
         if font is None:
             font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.FONTSTYLE_NORMAL, 
                             wx.FONTWEIGHT_NORMAL)
+            _PSET('FONT2', font, 'font')
         secondary = font.GetFaceName()
         faces = { 
                   self.FONT_PRIMARY   : primary,
@@ -560,14 +560,17 @@ class StyleMgr(object):
         else:
             return False
 
-    def LoadStyleSheet(self, style_sheet):
+    def LoadStyleSheet(self, style_sheet, force=False):
         """Loads a custom style sheet and returns True on success
         @param style_sheet: path to style sheet to load
+        @keyword force: Force reparse of style sheet, default is to use cached
+                        data when available
         @return: whether style sheet was loaded or not
         @rtype: bool
 
         """
-        if os.path.exists(style_sheet):
+        if isinstance(style_sheet, basestring) and os.path.exists(style_sheet) and \
+           ((force or not len(self.styles)) or style_sheet != self.style_set):
             reader = util.GetFileReader(style_sheet)
             if reader == -1:
                 self.LOG("[styles][err] Failed to open style sheet: %s" % \
@@ -576,11 +579,14 @@ class StyleMgr(object):
             ret_val = self.SetStyles(self.ParseStyleData(reader.read()))
             reader.close()
             return ret_val
-        else:
+        elif not len(self.styles):
             self.LOG("[styles] The style sheet %s does not exists" % \
                                                                     style_sheet)
             self.SetStyles(self.DefaultStyleDictionary())
             return False
+        else:
+            self.LOG("[styles][info] Using cached style data")
+            return True
 
     def MergeFonts(self, style_dict, font_dict):
         """Does any string substitution that the style dictionary
