@@ -35,8 +35,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: plugdlg.py 400 2007-08-31 14:50:10Z CodyPrecord $"
-__revision__ = "$Revision: 400 $"
+__cvsid__ = "$Id: plugdlg.py 516 2007-09-24 08:29:23Z CodyPrecord $"
+__revision__ = "$Revision: 516 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -49,7 +49,7 @@ import wx.lib.delayedresult as delayedresult
 # import wx.lib.mixins.listctrl as listmix
 import extern.listctrl as listmix
 import ed_glob
-from profiler import Profile_Get
+from profiler import Profile_Get, Profile_Set
 import ed_event
 import plugin
 import util
@@ -64,6 +64,32 @@ BASE_URL = "http://editra.org/"
 PLUGIN_REPO = "http://editra.org/plugins.php?list=True&py=" + PY_VER
 
 _ = wx.GetTranslation
+
+#--------------------------------------------------------------------------#
+
+def MakeThemeTool(tool_id):
+    """Makes a themed bitmap for the tool book of the plugin dialog.
+    @param tool_id: An art identifier id
+    @return: 32x32 bitmap
+    @todo: figure out cause of black artifacts on wxmac
+
+    """
+    osize = Profile_Get('ICON_SZ', 'size_tuple', (24, 24))
+    Profile_Set('ICON_SZ', (32, 32))
+    base = wx.ArtProvider.GetBitmap(str(tool_id), wx.ART_TOOLBAR)
+    Profile_Set('ICON_SZ', osize)
+    over = wx.ArtProvider.GetBitmap(str(ed_glob.ID_PLUGMGR), wx.ART_MENU)
+    if base.IsOk() and over.IsOk():
+        # Draw overlay onto button
+        mdc = wx.MemoryDC()
+        mdc.SelectObject(base)
+        mdc.SetBrush(wx.TRANSPARENT_BRUSH)
+        mdc.SetPen(wx.TRANSPARENT_PEN)
+        mdc.DrawBitmap(over, 15, 15, True)
+        return mdc.GetAsBitmap()
+    else:
+        return wx.ArtProvider.GetBitmap(wx.ART_WARNING, size=(32, 32))
+    
 #--------------------------------------------------------------------------#
 
 class PluginDialog(wx.Frame):
@@ -222,6 +248,7 @@ class DownloadStatusBar(wx.StatusBar):
         @postcondition: Progress bar is shown and animated
 
         """
+        self.Reposition()
         self.prog.Show()
         self.timer.Start(100)
 
@@ -247,15 +274,12 @@ class PluginPages(wx.Toolbook):
         # Create Pages
         self._imglst = wx.ImageList(32, 32)
         self._imgind = dict()
-        self._imgind[CONFIG_PG] = self._imglst.Add(wx.ArtProvider.GetBitmap( 
-                                                   str(ed_glob.ID_PLUGIN_CFG), \
-                                                       wx.ART_OTHER))
-        self._imgind[DOWNLOAD_PG] = self._imglst.Add(wx.ArtProvider.GetBitmap(
-                                                  str(ed_glob.ID_PLUGIN_DL), \
-                                                      wx.ART_OTHER))
-        self._imgind[INSTALL_PG] = self._imglst.Add(wx.ArtProvider.GetBitmap( 
-                                                  str(ed_glob.ID_PLUGIN_INST), \
-                                                      wx.ART_OTHER))
+        bmp = MakeThemeTool(ed_glob.ID_PREF)
+        self._imgind[CONFIG_PG] = self._imglst.Add(bmp)
+        bmp = MakeThemeTool(ed_glob.ID_WEB)
+        self._imgind[DOWNLOAD_PG] = self._imglst.Add(bmp)
+        bmp = MakeThemeTool(ed_glob.ID_PACKAGE)
+        self._imgind[INSTALL_PG] = self._imglst.Add(bmp)
         self._config = ConfigPanel(self)
         self._download = DownloadPanel(self)
         self._install = InstallPanel(self)
@@ -797,8 +821,8 @@ class InstallPanel(wx.Panel):
 
         if not len(self._install.GetItems()):
             # All plugins installed correctly
-            grand_p = self.GetGrandParent()
-            grand_p.SetStatusText(_("Finished Installing Plugins"), 0)
+            grand_p = self.GetTopLevelParent()
+            grand_p.SetStatusText(_("Successfully Installed Plugins"), 0)
             dlg = wx.MessageDialog(self, _("Go to configuration page?"),
                                    _("Finished Installing Plugins"), 
                                    style=wx.YES_NO | wx.CENTER | \
