@@ -31,8 +31,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: prefdlg.py 367 2007-08-20 07:53:06Z CodyPrecord $"
-__revision__ = "$Revision: 367 $"
+__svnid__ = "$Id: prefdlg.py 546 2007-09-27 11:36:02Z CodyPrecord $"
+__revision__ = "$Revision: 546 $"
 
 #----------------------------------------------------------------------------#
 # Dependancies
@@ -68,6 +68,68 @@ _ = wx.GetTranslation
 #     plist = ProfileListCtrl(prof_panel)
 #     border.Add(plist, 1, wx.EXPAND)
 #     prof_panel.SetSizer(border)
+from wx import ImageFromStream, BitmapFromImage, EmptyIcon
+import cStringIO, zlib
+
+
+def getData():
+    """Gets the data of the button background"""
+    return zlib.decompress(
+'x\xda\x01A\x02\xbe\xfd\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00 \x00\
+\x00\x00 \x08\x06\x00\x00\x00szz\xf4\x00\x00\x00\x04sBIT\x08\x08\x08\x08|\
+\x08d\x88\x00\x00\x01\xf8IDATX\x85\xed\x97?n\x1aA\x14\x87\xbf\xd9Y\xb0\xdd\
+\x10\x05\x87\xd2[Q`"\x91\x8a\x03P\xc6\x11R\xdcE.R9F\xb2\x94\x0b87\xc8\x01\\D\
+\x91S\xc5\xce\t\x9c.\x17\xa0\n\x8a%\xba\x95\x90\xe8b\x1cX\x8b\xc4\xec<&\x05\
+\x7fb\xc0`b0n\xf8I[\xcc\xe8\xcd\xfb}\xf3\xdehF\xab\x18T\x1cx\x96\xc9d\x0e\
+\xb5\xd6)\xe6(\x11)\x97J\xa5}\xe0;P\xeb\xcd\xabk1\xbb\xa9T*\x97\xcdfw\xb6\
+\x9eo\xb1\xfed}\x9e\xfe\x9c\xff<\xe7\xf4\xeb)\xc5b\xf1\xb8\\.\xbf\x06\xa4\
+\x07\xe0D"\x917\x85\xbd\xc2\xfbd2\x19\xf3<o\xae\xc6\xc3\xaaT*\x1c\xbc;\xf8\
+\xd0l6\xf7\x01Q@n\xfb\xe5\xf6\xb7|>\x7f\xaf\xc6\xd7U\xadV9\xfatt\xec\xfb\xfe\
+[wc\xc3\xdb\xf3<\x8f \xb8\x04\xecB\x00b\xb1Gln\xa6w|\xdf\xff\xe8F\\\xf7U"\
+\x91 \x08\x1a\xb7.\xb4\xd6b\xadE)\x85R\xea\xd6\xf8Iz\x9aNsv\xf6\xe3\xd05\xc6\
+P\xffU\x9fl\xdc\xad\x8cb6\xd3\x91\xbcm\x9br\x8d\x18\x1aS\xec~|\x16\xb8+\x97\
+\x11\x83+"4\x1a\xc1\xdd\x01f\x90\x88\xd0iA}\xb0\x05\x137d\xa7\t\x9a\xbc\xb4\
+\'c\x0c\xae\x18\xe12x\xa0\n\x18\xc1\r\x8d\xa1V\xbb@k=\xf3\xc9\x9eV\xd6ZD\x84\
+\xd0\x18\x14\xdd\xca\xc4\x1f\xc7\x89F\xa2\xfd \xad5\xd1\xe8\xca\\\x0c[\xad+D\
+\xe4\xdf8lQ\xbb\xe8<\x07}\x80ai\xadY\x89\xae\x0e\xcc)\xa5X[]\xc3q\x9c\x91\
+\xf8\xb6m\x13\x86!\xc6\x84\xd8\xa1\x8cW\xad?\x03\x00\x039\xc7\x01\x8c\x93\
+\xab#@\xe7B\x1a\xa2\xc3ZK\xbb}\xb3\xd18\xfd7\xc0\xbc5Z\xcb%\xc0\x12`\t\xb0\
+\x04X\x02,V/\x1c\xe0\xcb\x03\x02\xfc\x06\xc8\xd1y\x90\x16\xfd}\xa6\xf3/\x8a\
+\x03\x14\x80\xfa\x02\xcd\xeb\xc0\xeep9\n\x0b\x04(\xdc\xd4\x0f\xa7\xdb\x8e\
+\x93{4>\xe9z\xf4\x0f\xff_\x17\xe2 \x06n\xab\xb1\xf7\x00\x00\x00\x00IEND\xaeB\
+`\x82\x11\x87\x03\xa2' )
+
+def getBitmap():
+    """Gets the bitmap of the button base"""
+    return BitmapFromImage(getImage())
+
+def getImage():
+    """Gets the image of the button base"""
+    stream = cStringIO.StringIO(getData())
+    return ImageFromStream(stream)
+
+def MakeThemeTool(tool_id):
+    """Makes a themed bitmap for the tool book of the pref dialog.
+    @param tool_id: An art identifier id
+    @return: 32x32 bitmap
+
+    """
+    osize = Profile_Get('ICON_SZ', 'size_tuple', (24, 24))
+    Profile_Set('ICON_SZ', (24, 24))
+    over = wx.ArtProvider.GetBitmap(str(tool_id), wx.ART_TOOLBAR)
+    Profile_Set('ICON_SZ', osize)
+    mdc = wx.MemoryDC(getBitmap())
+    if over.IsOk():
+        # Create overlay
+        if over.GetSize() != (24, 24):
+            over = over.ConvertToImage()
+            over.Rescale(24, 24, wx.IMAGE_QUALITY_HIGH)
+            over = over.ConvertToBitmap()
+
+        # Draw overlay onto button
+        mdc.SetBrush(wx.TRANSPARENT_BRUSH)
+        mdc.DrawBitmap(over, 4, 4, True)
+    return mdc.GetAsBitmap()
 
 #----------------------------------------------------------------------------#
 
@@ -147,18 +209,12 @@ class PrefTools(wx.Toolbook):
         # Attributes
         self.LOG = wx.GetApp().GetLog()
         self._imglst = wx.ImageList(32, 32)
-        self._imglst.Add(wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF_GENERAL), 
-                                                       wx.ART_OTHER))
-        self._imglst.Add(wx.ArtProvider.\
-                            GetBitmap(str(ed_glob.ID_PREF_APPEARANCE),
-                                                       wx.ART_OTHER))
-        self._imglst.Add(wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF_DOCUMENT),
-                                                       wx.ART_OTHER))
-        self._imglst.Add(wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF_UPDATE),
-                                                       wx.ART_OTHER))
-#      self._imglst.Add(wx.ArtProvider.GetBitmap(str(ed_glob.ID_PREF_ADVANCED),
-#                                                        wx.ART_OTHER))
+        self._imglst.Add(MakeThemeTool(ed_glob.ID_PREF))
+        self._imglst.Add(MakeThemeTool(ed_glob.ID_THEME))
+        self._imglst.Add(MakeThemeTool(ed_glob.ID_DOCPROP))
+        self._imglst.Add(MakeThemeTool(ed_glob.ID_WEB))
         self.SetImageList(self._imglst)
+
         self.AddPage(GeneralPanel(self), _("General"), 
                      imageId=self.GENERAL_PG)
         self.AddPage(AppearancePanel(self), _("Appearance"), 
@@ -194,13 +250,20 @@ class PrefTools(wx.Toolbook):
     def OnPaint(self, evt):
         """Paint the toolbar's background
         @todo: it would be nice to use a unified toolbar style on osx
+        @note: unified toolbar is available in 2.8.5+ maybe create custom
+               window using native toolbar to accomidate this.
 
         """
+        # This is odd but I have recieved a number of error reports where
+        # wx is being reported as None in this function
+        if 'wx' not in globals() or wx is None:
+            evt.Skip()
+            return
+
         dc = wx.PaintDC(self)
         gc = wx.GraphicsContext.Create(dc)
         col1 = wx.SystemSettings_GetColour(wx.SYS_COLOUR_3DFACE)
         col2 = util.AdjustColour(col1, -20)
-#         col1 = util.AdjustColour(col1, -20)
         rect = self.GetToolBar().GetRect()
 
         # Create the background path
@@ -209,18 +272,9 @@ class PrefTools(wx.Toolbook):
 
         gc.SetPen(wx.Pen(col1, 1))
         grad = gc.CreateLinearGradientBrush(0, 0, 0, rect.height, col1, col2)
-#         grad = gc.CreateBrush(wx.Brush(col1))
         gc.SetBrush(grad)
         gc.DrawPath(path)
 
-#         path = gc.CreatePath()
-#         gc.SetPen(wx.Pen(col1, 1, wx.TRANSPARENT))
-#         path.AddRectangle(0, rect.height/2, rect.width, 
-#                           int((rect.height + 3)/2))
-#         grad = gc.CreateLinearGradientBrush(0, rect.height, 0, 
-#                                             int(rect.height/2), col1, col2)
-#         gc.SetBrush(grad)
-#         gc.DrawPath(path)
         evt.Skip()
 
 class PrefPanelBase(wx.Panel):
@@ -244,6 +298,13 @@ class PrefPanelBase(wx.Panel):
         @param evt: Event that called this handler
 
         """
+        # This is odd but I have recieved a number of error reports where
+        # wx is being reported as None in this function requires more 
+        # investigation as I cannot reproduce
+        if 'wx' not in globals() or wx is None:
+            evt.Skip()
+            return
+
         dc = wx.PaintDC(self)
         gc = wx.GraphicsContext.Create(dc)
         col1 = wx.SystemSettings_GetColour(wx.SYS_COLOUR_3DFACE)
@@ -328,6 +389,9 @@ class GeneralPanel(PrefPanelBase):
                          default=Profile_Get('FHIST_LVL', 'str'))
         fhsizer = wx.BoxSizer(wx.HORIZONTAL)
         fhsizer.AddMany([(fh_lbl, 0), ((5, 5), 0), (fh_ch, 0)])
+        win_cb = wx.CheckBox(self, ed_glob.ID_NEW_WINDOW,
+                             _("Open files in new windows by default"))
+        win_cb.SetValue(Profile_Get('OPEN_NW'))
         pos_cb = wx.CheckBox(self, ed_glob.ID_PREF_SPOS, 
                              _("Remember File Position"))
         pos_cb.SetValue(Profile_Get('SAVE_POS'))
@@ -354,10 +418,11 @@ class GeneralPanel(PrefPanelBase):
                        (session_cb, (4, 2), (1, 2)),
                        (splash_cb, (5, 2), (1, 2))])
         sizer.AddMany([(file_lbl, (7, 1)),
-                       (fhsizer, (7, 2), (1, 2)), (pos_cb, (8, 2), (1, 3)),
-                       (chkmod_cb, (9, 2), (1, 2))])
-        sizer.AddMany([(locale, (11, 1)),
-                       (lsizer, (11, 2), (1, 3))])
+                       (fhsizer, (7, 2), (1, 2)), (win_cb, (8, 2), (1, 3)),
+                       (pos_cb, (9, 2), (1, 3)),
+                       (chkmod_cb, (10, 2), (1, 2))])
+        sizer.AddMany([(locale, (12, 1)),
+                       (lsizer, (12, 2), (1, 3))])
         self.SetSizer(sizer)
 
     def OnCheck(self, evt):
@@ -369,7 +434,8 @@ class GeneralPanel(PrefPanelBase):
         e_id = evt.GetId()
         e_obj = evt.GetEventObject()
         if e_id in [ed_glob.ID_APP_SPLASH, ed_glob.ID_PREF_SPOS,
-                    ed_glob.ID_PREF_CHKMOD, ed_glob.ID_SESSION]:
+                    ed_glob.ID_PREF_CHKMOD, ed_glob.ID_SESSION,
+                    ed_glob.ID_NEW_WINDOW]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
         elif e_id == ed_glob.ID_REPORTER:
             Profile_Set(ed_glob.ID_2_PROF[e_id], not e_obj.GetValue())
@@ -483,14 +549,17 @@ class DocGenPanel(wx.Panel):
         ww_cb.SetValue(Profile_Get('WRAP'))
 
         # Font Options
-        main = wx.GetApp().GetMainWindow()
         font_lbl = wx.StaticText(self, label=_("Primary Font") + u": ")
-        fnt = main.nb.GetCurrentCtrl().GetStyleFont()
+        fnt = Profile_Get('FONT1', 'font', wx.Font(10, wx.FONTFAMILY_MODERN, 
+                                                   wx.FONTSTYLE_NORMAL, 
+                                                   wx.FONTWEIGHT_NORMAL))
         fpicker = PyFontPicker(self, self.ID_FONT_PICKER, fnt)
         tt = wx.ToolTip(_("Sets the main/default font of the document"))
         fpicker.SetToolTip(tt)
         font_lbl2 = wx.StaticText(self, label=_("Secondary Font") + u": ")
-        fnt = main.nb.GetCurrentCtrl().GetStyleFont(False)
+        fnt = Profile_Get('FONT2', 'font', wx.Font(10, wx.FONTFAMILY_SWISS,
+                                                   wx.FONTSTYLE_NORMAL, 
+                                                   wx.FONTWEIGHT_NORMAL))
         fpicker2 = PyFontPicker(self, self.ID_FONT_PICKER2, fnt)
         tt = wx.ToolTip(_("Sets a secondary font used for special regions "
                           "when syntax highlighting is in use"))
@@ -509,7 +578,8 @@ class DocGenPanel(wx.Panel):
                        (font_lbl, (11, 1)), 
                        (fpicker, (11, 2), (1, 3), wx.EXPAND), 
                        (font_lbl2, (12, 1)),
-                       (fpicker2, (12, 2), (1, 3), wx.EXPAND)
+                       (fpicker2, (12, 2), (1, 3), wx.EXPAND),
+                       ((5, 5), (13, 0))
                        ])
         self.SetSizer(sizer)
 
@@ -518,14 +588,15 @@ class DocGenPanel(wx.Panel):
         e_id = evt.GetId()
         if e_id in [self.ID_FONT_PICKER, self.ID_FONT_PICKER2]:
             font = evt.GetValue()
-            if font == wx.EmptyString:
+            if not isinstance(font, wx.Font) or font.IsNull():
                 return
+
             if e_id == self.ID_FONT_PICKER:
                 Profile_Set('FONT1', font, 'font')
             else:
                 Profile_Set('FONT2', font, 'font')
-            main = wx.GetApp().GetMainWindow()
-            if main:
+
+            for main in wx.GetApp().GetMainWindows():
                 for stc in main.nb.GetTextControls():
                     stc.SetStyleFont(font, e_id == self.ID_FONT_PICKER)
                     stc.UpdateAllStyles()
@@ -546,8 +617,7 @@ class DocGenPanel(wx.Panel):
                     ed_glob.ID_SHOW_WS, ed_glob.ID_WORD_WRAP,
                     ed_glob.ID_PREF_AALIAS]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
-            mainw = wx.GetApp().GetMainWindow()
-            if mainw is not None:
+            for mainw in wx.GetApp().GetMainWindows():
                 mainw.nb.UpdateTextControls()
         else:
             evt.Skip()
@@ -592,6 +662,8 @@ class DocCodePanel(wx.Panel):
                             0, 100, size=(-1, 15), style=wx.SL_HORIZONTAL | \
                             wx.SL_AUTOTICKS | wx.SL_LABELS)
         edge_sl.SetTickFreq(5, 1)
+        if wx.Platform == '__WXMAC__':
+            edge_sl.SetWindowVariant(wx.WINDOW_VARIANT_SMALL)
         ind_cb = wx.CheckBox(self, ed_glob.ID_INDENT_GUIDES, 
                              _("Indentation Guides"))
         ind_cb.SetValue(Profile_Get('GUIDES'))
@@ -630,8 +702,8 @@ class DocCodePanel(wx.Panel):
                     ed_glob.ID_AUTOCOMP, ed_glob.ID_AUTOINDENT,
                     ed_glob.ID_PREF_EDGE, ed_glob.ID_VI_MODE]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
-            mainw = wx.GetApp().GetMainWindow()
-            if mainw is not None:
+
+            for mainw in wx.GetApp().GetMainWindows():
                 mainw.nb.UpdateTextControls()
         else:
             evt.Skip()
@@ -646,8 +718,8 @@ class DocCodePanel(wx.Panel):
         if e_id == ed_glob.ID_PREF_EDGE:
             val = e_obj.GetValue()
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
-            mainw = wx.GetApp().GetMainWindow()
-            if mainw is not None:
+
+            for mainw in wx.GetApp().GetMainWindows():
                 for stc in mainw.nb.GetTextControls():
                     stc.SetEdgeColumn(val)
         else:
@@ -683,6 +755,9 @@ class DocSyntaxPanel(wx.Panel):
         @note: Controls are layed out using L{wx.GridBagSizer}
 
         """
+        sizer = wx.BoxSizer(wx.VERTICAL)
+        
+
         # Syntax Settings
         syn_cb = wx.CheckBox(self, ed_glob.ID_SYNTAX, _("Syntax Highlighting"))
         syn_cb.SetValue(Profile_Get('SYNTAX'))
@@ -690,32 +765,42 @@ class DocSyntaxPanel(wx.Panel):
                             choices=util.GetResourceFiles(u'styles', 
                                                           get_all=True),
                             default=Profile_Get('SYNTHEME', 'str'))
+
         line = wx.StaticLine(self, size=(-1, 2))
         lsizer = wx.BoxSizer(wx.VERTICAL)
         lsizer.Add(line, 0, wx.EXPAND)
         lst_lbl = wx.StaticText(self, label=_("Filetype Associations") + u": ")
 
         # Layout the controls
-        sizer = wx.GridBagSizer()
-        sizer.Add((5, 5), (0, 0))
         hsizer = wx.BoxSizer(wx.HORIZONTAL)
         hsizer.AddMany([(syn_cb, 0, wx.ALIGN_LEFT), ((5, 5), 1, wx.EXPAND),
                         (wx.StaticText(self, label=_("Color Scheme") + u": "), \
                         0, wx.ALIGN_LEFT),
-                        (syntheme, 1, wx.EXPAND)])
-        sizer.AddMany([(hsizer, (1, 1), (1, 4), wx.EXPAND), 
-                       (lsizer, (3, 1), (1, 4), wx.EXPAND),
-                       (lst_lbl, (4, 1))])
-        if wx.Platform == '__WXMAC__':
-            # For some reason the list control flows out of bounds if this is 
-            # not added on OS X
-            sizer.Add((5, 5), (1, 5), (1, 3), wx.EXPAND)
-        sizer.Add(self._elist, (5, 1), (10, 4), wx.EXPAND)
-        sizer.Add((1, 1), (15, 1))
+                        (syntheme, 0, wx.EXPAND), ((5, 5), 0)])
+
+        sizer.AddMany([((15, 15), 0), 
+                       (hsizer, 0, wx.EXPAND),
+                       ((5, 5), 0),
+                       (lsizer, 0, wx.EXPAND),
+                       ((15, 15), 0),
+                       (lst_lbl, 0, wx.ALIGN_LEFT)])
+
+
+        hsizer2 = wx.BoxSizer(wx.HORIZONTAL)
+        hsizer2.Add((5, 5), 0)
+        hsizer2.Add(self._elist, 1, wx.EXPAND)
+        hsizer2.Add((5, 5), 0)
+
+        sizer.Add((10, 10), 0)
+        sizer.Add(hsizer2, 1, wx.EXPAND)
+        sizer.Add((20, 20), 0)
         sizer.Add(wx.Button(self, wx.ID_DEFAULT, 
-                  _("Revert to Default")), (16, 1))
-        sizer.Add((2, 2), (17, 1))
-        self.SetSizer(sizer)
+                  _("Revert to Default")), 0, wx.ALIGN_LEFT)
+        sizer.Add((10, 10), 0)
+
+        msizer = wx.BoxSizer(wx.HORIZONTAL)
+        msizer.AddMany([((5, 5), 0), (sizer, 1, wx.EXPAND), ((5, 5), 0)])
+        self.SetSizer(msizer)
 
     def OnButton(self, evt):
         """Reset button handler
@@ -740,8 +825,8 @@ class DocSyntaxPanel(wx.Panel):
         e_obj = evt.GetEventObject()
         if e_id in [ed_glob.ID_SYNTAX, ed_glob.ID_PREF_SYNTHEME]:
             Profile_Set(ed_glob.ID_2_PROF[e_id], e_obj.GetValue())
-            mainw = wx.GetApp().GetMainWindow()
-            if mainw is not None:
+
+            for mainw in wx.GetApp().GetMainWindows():
                 mainw.nb.UpdateTextControls()
         else:
             evt.Skip()
@@ -789,7 +874,7 @@ class AppearancePanel(PrefPanelBase):
         # Layout Section
         perspect_lbl = wx.StaticText(self, wx.ID_ANY, \
                                      _("Default Perspective") + u": ")
-        mainw = wx.GetApp().GetMainWindow()
+        mainw = wx.GetApp().GetActiveWindow()
         if mainw is not None:
             pchoices = mainw.GetPerspectiveList()
         else:
@@ -816,8 +901,9 @@ class AppearancePanel(PrefPanelBase):
         # Activate Metal Style for OSX
         if wx.Platform == '__WXMAC__':
             m_cb = wx.CheckBox(self, ed_glob.ID_PREF_METAL, \
-                               _("Use Metal Style (OS X Only)"))
+                               _("Use Metal Style"))
             m_cb.SetValue(Profile_Get('METAL', 'bool', False))
+            m_cb.SetToolTip(wx.ToolTip(_("Restart Required")))
         else:
             m_cb = (0, 0)
 
@@ -852,24 +938,6 @@ class AppearancePanel(PrefPanelBase):
         elif e_id == ed_glob.ID_PREF_METAL:
             windows = wx.GetApp().GetOpenWindows()
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
-            for window in windows.values():
-                sty = None
-                if isinstance(window[0], wx.Frame):
-                    if not val:
-                        sty = ~wx.FRAME_EX_METAL
-                    else:
-                        sty = wx.FRAME_EX_METAL
-                elif isinstance(window[0], wx.Dialog):
-                    if not val:
-                        sty = ~wx.DIALOG_EX_METAL
-                    else:
-                        sty = wx.DIALOG_EX_METAL
-                else:
-                    pass
-                if sty is not None:
-                    window[0].SetExtraStyle(sty)
-                    window[0].Refresh()
-                    window[0].Update()
         else:
             evt.Skip()
 
@@ -885,15 +953,23 @@ class AppearancePanel(PrefPanelBase):
             if e_id == ed_glob.ID_PREF_ICONSZ:
                 val = (int(val), int(val))
             Profile_Set(ed_glob.ID_2_PROF[e_id], val)
-            toolbar = wx.GetApp().GetMainWindow().GetToolBar()
-            if toolbar is not None and \
-               (toolbar.GetToolTheme() != Profile_Get('ICONS')) \
-               or (toolbar.GetToolSize() != Profile_Get('ICON_SZ')):
-                toolbar.ReInit()
+            for mainw in wx.GetApp().GetMainWindows():
+                toolbar = mainw.GetToolBar()
+                if toolbar is not None and \
+                   (toolbar.GetToolTheme() != Profile_Get('ICONS')) \
+                   or (toolbar.GetToolSize() != Profile_Get('ICON_SZ')):
+                    toolbar.ReInit()
+                mainw.UpdateToolBar()
+
+                # Update Search Bar
+                # TODO for some reason this doesnt work with 2.8.5
+                sbar = mainw.FindWindowById(ed_glob.ID_COMMAND_BAR)
+                if sbar:
+                    sbar.UpdateIcons()
+
         elif e_id == ed_glob.ID_PERSPECTIVES:
             Profile_Set('DEFAULT_VIEW', e_obj.GetValue())
-            main_win = wx.GetApp().GetMainWindow()
-            if main_win is not None:
+            for main_win in wx.GetApp().GetMainWindows():
                 main_win.SetPerspective(Profile_Get('DEFAULT_VIEW'))
         else:
             evt.Skip()
@@ -945,7 +1021,7 @@ class UpdatePanel(PrefPanelBase):
         cur_box = wx.StaticBox(self, ID_CURR_BOX, _("Installed Version"))
         cur_sz = wx.StaticBoxSizer(cur_box, wx.HORIZONTAL)
         cur_sz.SetMinSize(wx.Size(150, 40))
-        cur_ver = wx.StaticText(self, wx.ID_ANY,  ed_glob.version)
+        cur_ver = wx.StaticText(self, wx.ID_ANY,  ed_glob.VERSION)
         cur_sz.Add(cur_ver, 0, wx.ALIGN_CENTER_HORIZONTAL)
         e_update = updater.UpdateProgress(self, ed_glob.ID_PREF_UPDATE_BAR)
         upd_box = wx.StaticBox(self, ID_LATE_BOX, _("Latest Version"))
@@ -1067,7 +1143,7 @@ class ProfileListCtrl(wx.ListCtrl,
 class ExtListCtrl(wx.ListCtrl, 
                   listmix.ListCtrlAutoWidthMixin, 
                   listmix.TextEditMixin):
-    """Class to manage the profile editor
+    """Class to manage the file extension associations
     @summary: Creates a list control for showing file type to file extension
               associations as well as providing an interface to editing these
               associations
@@ -1083,7 +1159,7 @@ class ExtListCtrl(wx.ListCtrl,
         wx.ListCtrl.__init__(self, parent, wx.ID_ANY, 
                              wx.DefaultPosition, wx.DefaultSize, 
                              style=wx.LC_REPORT | wx.LC_SORT_ASCENDING | \
-                                   wx.LC_VRULES)
+                                   wx.LC_VRULES | wx.BORDER)
 
         listmix.ListCtrlAutoWidthMixin.__init__(self)
         listmix.TextEditMixin.__init__(self)
