@@ -35,8 +35,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: style_editor.py 371 2007-08-21 02:14:30Z CodyPrecord $"
-__revision__ = "$Revision: 371 $"
+__svnid__ = "$Id: style_editor.py 551 2007-09-28 07:58:06Z CodyPrecord $"
+__revision__ = "$Revision: 551 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -47,7 +47,8 @@ import wx.lib.colourselect as  csel
 import ed_glob
 from profiler import Profile_Get, Profile_Set
 import ed_stc
-from ed_style import StyleItem
+from ed_style import StyleItem, StyleMgr
+import ed_event
 import util
 import syntax.syntax as syntax
 
@@ -72,7 +73,7 @@ SETTINGS_IDS = [ ID_FORE_COLOR, ID_BACK_COLOR, ID_BOLD, ID_ITALIC,
 class StyleEditor(wx.Dialog):
     """This class creates the window that contains the controls
     for editing/configuring the syntax highlighting styles it acts
-    as a a graphical way to interact with the L{ed_style.StyleMgr}.
+    as a graphical way to interact with the L{ed_style.StyleMgr}.
 
     @see: ed_style.StyleMgr
     """
@@ -97,12 +98,11 @@ class StyleEditor(wx.Dialog):
         self.OpenPreviewFile('cpp')
 
         # Main Sizer
-        self.SetSizeHints(300, 250)
         self.sizer = wx.BoxSizer(wx.VERTICAL)
         self.sizer.Add((10, 10)) # Spacer
 
         # Control Panel
-        self.ctrl_pane = wx.Panel(self, wx.ID_ANY, style=wx.RAISED_BORDER)
+        self.ctrl_pane = wx.Panel(self, wx.ID_ANY)
         ctrl_sizer = wx.BoxSizer(wx.HORIZONTAL)  # Main Control Sizer
         left_colum = wx.BoxSizer(wx.VERTICAL)    # Left Column
         right_colum = wx.BoxSizer(wx.VERTICAL)   # Right Column
@@ -121,10 +121,12 @@ class StyleEditor(wx.Dialog):
         ctrl_sizer.Add(wx.StaticLine(self.ctrl_pane, size=(-1, 2), 
                                      style = wx.LI_VERTICAL), 
                        0, wx.ALIGN_CENTER_HORIZONTAL | wx.EXPAND)
+        ctrl_sizer.Add((5, 5), 0)
 
         # Control Panel Right Column
-        right_colum.Add(self.Settings(), 0, wx.ALIGN_LEFT)
-        ctrl_sizer.Add(right_colum, 0, wx.ALIGN_RIGHT)
+        right_colum.Add(self.Settings(), 1, wx.ALIGN_LEFT | wx.EXPAND)
+        ctrl_sizer.Add(right_colum, 1, wx.ALIGN_RIGHT | wx.EXPAND)
+        ctrl_sizer.Add((5, 5), 0)
 
         # Finish Control Panel Setup
         self.ctrl_pane.SetSizer(ctrl_sizer)
@@ -132,7 +134,7 @@ class StyleEditor(wx.Dialog):
 
         # Preview Area
         pre_sizer = wx.BoxSizer(wx.HORIZONTAL)
-        pre_sizer.AddMany([(10, 10), 
+        pre_sizer.AddMany([((10, 10), 0), 
                            (wx.StaticText(self, label=_("Preview") + u": "), 
                             0, wx.ALIGN_LEFT)])
         self.sizer.AddMany([((10, 10), 0), (pre_sizer, 0, wx.ALIGN_LEFT),
@@ -141,9 +143,9 @@ class StyleEditor(wx.Dialog):
         # Create Buttons
         b_sizer = wx.BoxSizer(wx.HORIZONTAL)
         cancel_b = wx.Button(self, wx.ID_CANCEL, _("Cancel"))
-        cancel_b.SetDefault()
         save_b = wx.Button(self, wx.ID_SAVE, _("Export"))
         ok_b = wx.Button(self, wx.ID_OK, _("Ok"))
+        ok_b.SetDefault()
         b_sizer.AddMany([cancel_b, save_b, ok_b])
         self.sizer.Add(b_sizer, 0, wx.ALIGN_RIGHT | \
                                    wx.ALIGN_CENTER_VERTICAL | wx.ALL, 5)
@@ -164,7 +166,7 @@ class StyleEditor(wx.Dialog):
         self.Bind(wx.EVT_CHECKBOX, self.OnCheck)
         self.Bind(wx.EVT_CLOSE, self.OnClose)
         self.Bind(wx.EVT_LISTBOX, self.OnListBox)
-        self.Bind(csel.EVT_COLOURSELECT, self.OnColor)
+        self.Bind(ed_event.EVT_NOTIFY, self.OnColor)
         self.preview.Bind(wx.EVT_LEFT_UP, self.OnTextRegion)
         self.preview.Bind(wx.EVT_KEY_UP, self.OnTextRegion)
     #--- End Init ---#
@@ -227,7 +229,7 @@ class StyleEditor(wx.Dialog):
         """
         if ed_glob.CONFIG['STYLES_DIR'] == ed_glob.CONFIG['SYS_STYLES_DIR']:
             user_config = os.path.join(wx.GetHomeDir(), 
-                                        "." + ed_glob.prog_name, 'styles')
+                                        "." + ed_glob.PROG_NAME, 'styles')
             if not os.path.exists(user_config):
                 try:
                     os.mkdir(user_config)
@@ -259,18 +261,19 @@ class StyleEditor(wx.Dialog):
                 ss_c.SetItems(ss_lst)
                 ss_c.SetStringSelection(sel)
                 self.styles_orig = self.DuplicateStyleDict(self.styles_new)
-            except IOError,msg:
+            except IOError, msg:
                 self.LOG('[style_editor][err] Failed to export style sheet')
                 self.LOG('[style_editor][sys error] %s' % msg)
             else:
-                # Update editor to use new sheet
-                sheet = os.path.basename(sheet_path).split(u'.')[0]
-                Profile_Set('SYNTHEME', sheet)
-                mainw = wx.GetApp().GetMainWindow()
-                if mainw is not None:
-                    mainw.nb.UpdateTextControls()
-                    mainw.SetStatusText(_("Chaned color scheme to %s") % sheet,
-                                        ed_glob.SB_INFO)
+                if sheet_path.startswith(ed_glob.CONFIG['STYLES_DIR']) or \
+                   sheet_path.startswith(ed_glob.CONFIG['SYS_STYLES_DIR']):
+                    # Update editor windows to use new style sheet
+                    sheet = os.path.basename(sheet_path).split(u'.')[0]
+                    Profile_Set('SYNTHEME', sheet)
+                    for mainw in wx.GetApp().GetMainWindows():
+                        mainw.nb.UpdateTextControls()
+                        mainw.SetStatusText(_("Changed color scheme to %s") % \
+                                            sheet, ed_glob.SB_INFO)
         return result
 
     def GenerateStyleSheet(self):
@@ -332,26 +335,25 @@ class StyleEditor(wx.Dialog):
         fground_sizer = wx.BoxSizer(wx.HORIZONTAL)
         fground_lbl = wx.StaticText(self.ctrl_pane, 
                                     label=_("Foreground") + u": ")
-        fground_sel = csel.ColourSelect(self.ctrl_pane, ID_FORE_COLOR,
-                                        "#000000", (0, 0, 0), size=(80, 25))
+        fground_sel = ColourSetter(self.ctrl_pane, ID_FORE_COLOR, "#000000")
         fground_sizer.AddMany([((5, 5)), 
                                (fground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                               ((2, 2), 1, wx.EXPAND),
                                (fground_sel, 0, wx.ALIGN_CENTER_VERTICAL), 
                                ((5, 5))])
-        cbox_sizer.Add(fground_sizer, 0, wx.ALIGN_CENTER_VERTICAL)
+        cbox_sizer.Add(fground_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)
         cbox_sizer.Add((10, 10))
         # Background
         bground_sizer = wx.BoxSizer(wx.HORIZONTAL)
         bground_lbl = wx.StaticText(self.ctrl_pane, 
                                     label=_("Background") + u": ")
-        bground_sel = csel.ColourSelect(self.ctrl_pane, ID_BACK_COLOR, 
-                                        "#FFFFFF", (255, 255, 255), 
-                                        size=(80, 25))
+        bground_sel = ColourSetter(self.ctrl_pane, ID_BACK_COLOR, "#FFFFFF")
         bground_sizer.AddMany([((5, 5)), 
                                (bground_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                               ((2, 2), 1, wx.EXPAND),
                                (bground_sel, 0, wx.ALIGN_CENTER_VERTICAL), 
                                ((5, 5))])
-        cbox_sizer.Add(bground_sizer, 0, wx.ALIGN_LEFT)
+        cbox_sizer.Add(bground_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)
         setting_top.Add(cbox_sizer, 0, wx.ALIGN_TOP)
         # Attrib Box
         setting_top.Add((10, 10))
@@ -372,6 +374,7 @@ class StyleEditor(wx.Dialog):
         fh_sizer = wx.BoxSizer(wx.HORIZONTAL)
         font_box = wx.StaticBox(self.ctrl_pane, label=_("Font Settings") + u":")
         fbox_sizer = wx.StaticBoxSizer(font_box, wx.VERTICAL)
+
         # Font Face Name
         fsizer = wx.BoxSizer(wx.HORIZONTAL)
         flbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, _("Font") + u": ")
@@ -382,27 +385,27 @@ class StyleEditor(wx.Dialog):
         font_lst = ["%(primary)s", "%(secondary)s"]
         font_lst.extend(f_lst)
         fchoice = wx.Choice(self.ctrl_pane, ID_FONT, choices=font_lst)
-        fsizer.AddMany([((5, 5)), (flbl, 0, wx.ALIGN_CENTER_VERTICAL),
+        fsizer.AddMany([((5, 5), 0), (flbl, 0, wx.ALIGN_CENTER_VERTICAL),
                         (fchoice, 0, wx.ALIGN_CENTER_VERTICAL), ((5, 5))])
         fbox_sizer.Add(fsizer, 0, wx.ALIGN_LEFT)
+
         # Font Size
         fsize_sizer = wx.BoxSizer(wx.HORIZONTAL)
         fsize_lbl = wx.StaticText(self.ctrl_pane, wx.ID_ANY, _("Size") + u": ")
         fsizes = ['%(size)d', '%(size2)d']
-        for num in range(4, 21):
-            fsizes.append(str(num))
+        fsizes.extend([ str(x) for x in xrange(4, 21)])
         fs_choice = wx.Choice(self.ctrl_pane, ID_FONT_SIZE, 
                               choices = fsizes)
-        fsize_sizer.AddMany([((5, 5)), (fsize_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
-                             (fs_choice, 0, wx.ALIGN_CENTER_VERTICAL), 
-                             ((5, 5))])
-        fbox_sizer.AddMany([((5, 5)), (fsize_sizer, 0, wx.ALIGN_LEFT)])
-        fh_sizer.AddMany([((10, 10)), 
-                          (fbox_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL),
+        fsize_sizer.AddMany([((5, 5), 0), (fsize_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
+                             (fs_choice, 1, wx.EXPAND | wx.ALIGN_RIGHT), 
+                             ((5, 5), 0)])
+        fbox_sizer.AddMany([((5, 5)), (fsize_sizer, 0, wx.ALIGN_LEFT | wx.EXPAND)])
+        fh_sizer.AddMany([(fbox_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL),
                           ((10, 10))])
 
         # Build Section
-        setting_sizer.AddMany([(setting_top, 0, wx.ALIGN_CENTER_HORIZONTAL), 
+        setting_sizer.AddMany([(setting_top, 0, wx.ALIGN_CENTER_HORIZONTAL),
+                               ((10, 10), 1, wx.EXPAND),
                                (fh_sizer, 0, wx.ALIGN_CENTER_HORIZONTAL)])
         return setting_sizer
 
@@ -419,8 +422,10 @@ class StyleEditor(wx.Dialog):
         ss_lst.sort()
         ss_choice = wx.Choice(self.ctrl_pane, ed_glob.ID_PREF_SYNTHEME,
                               choices=ss_lst)
+        ss_choice.SetToolTip(wx.ToolTip(_("Base new theme of existing one")))
         ss_choice.SetStringSelection(Profile_Get('SYNTHEME', 'str'))
         ss_new = wx.CheckBox(self.ctrl_pane, wx.ID_NEW, _("New"))
+        ss_new.SetToolTip(wx.ToolTip(_("Start a blank new style")))
         ss_sizer.AddMany([((10, 10)), (ss_lbl, 0, wx.ALIGN_CENTER_VERTICAL), 
                           ((5, 0)),
                           (ss_choice, 0, wx.ALIGN_CENTER_VERTICAL), ((10, 0)), 
@@ -439,14 +444,14 @@ class StyleEditor(wx.Dialog):
                                   _("Style Tags") + u": ")
         style_tags = self.styles_orig.keys()
         style_tags.sort()
-        style_lst = wx.ListBox(self.ctrl_pane, ID_STYLES, size = (150, 100),
-                               choices = style_tags, style = wx.LB_SINGLE)
+        style_lst = wx.ListBox(self.ctrl_pane, ID_STYLES, size=(150, 100),
+                               choices=style_tags, style=wx.LB_SINGLE)
         style_sizer2.AddMany([(style_lbl, 0, wx.ALIGN_CENTER_VERTICAL),
                              (style_lst, 0, wx.ALIGN_CENTER_VERTICAL)])
-        style_sizer.AddMany([((10, 10)), 
+        style_sizer.AddMany([((10, 10), 0), 
                              (style_sizer2, 0, 
                               wx.ALIGN_CENTER_HORIZONTAL | wx.EXPAND), 
-                             ((10, 10))])
+                             ((10, 10), 0)])
         return style_sizer
 
     def OnCancel(self, evt):
@@ -456,6 +461,9 @@ class StyleEditor(wx.Dialog):
 
         """
         self.LOG('[style_editor] [cancel] Cancel Clicked Closing Window')
+        # HACK for some reason SetStyles isn't doing its job right now so
+        #      just set it directly for the time being.
+        StyleMgr.styles = self.styles_orig
         evt.Skip()
 
     def OnCheck(self, evt):
@@ -519,19 +527,8 @@ class StyleEditor(wx.Dialog):
         @param evt: event that called this handler
 
         """
-        e_id = evt.GetId()
-        e_obj = self.FindWindowById(e_id)
-        e_val = evt.GetValue()[0:3]
-        red = hex(e_val[0])
-        green = hex(e_val[1])
-        blue = hex(e_val[2])
-        hex_str = "#%s%s%s" % (red[2:].zfill(2).upper(),
-                               green[2:].zfill(2).upper(),
-                               blue[2:].zfill(2).upper())
-        e_obj.SetLabel(hex_str)
-        e_obj.SetValue(wx.Color(e_val[0], e_val[1], e_val[2]))
-
         # Update The Style data for current tag
+        e_id = evt.GetId()
         self.UpdateStyleSet(e_id)
 
     def OnTextRegion(self, evt):
@@ -571,12 +568,13 @@ class StyleEditor(wx.Dialog):
         @param evt: event that called this handler
 
         """
-        self.LOG('[style_editor] [Ok] Ok Clicked Closing Window')
+        self.LOG('[style_editor][info] Ok Clicked Closing Window')
         result = self.DiffStyles()
         if result == wx.ID_NO:
+            StyleMgr.styles = self.styles_orig
             evt.Skip()
         elif result == wx.ID_CANCEL:
-            self.LOG('[style_editor] Info Canceled closer')
+            self.LOG('[style_editor][info] canceled closing')
         else:
             result = self.ExportStyleSheet()
             if result != wx.ID_CANCEL:
@@ -648,7 +646,7 @@ class StyleEditor(wx.Dialog):
                 ctrl.SetValue(val_map[sid])
             elif c_type == "wxChoice":
                 ctrl.SetStringSelection(val_map[sid])
-            elif c_type == "wxBitmapButton":
+            elif isinstance(ctrl, ColourSetter):
                 # Note: must call set label before set value or the label
                 # is not redrawn
                 ctrl.SetLabel(val_map[sid][:7])
@@ -676,7 +674,7 @@ class StyleEditor(wx.Dialog):
             val = ctrl.GetValue()
         elif ctrl_t == 'wxChoice':
             val = ctrl.GetStringSelection()
-        elif ctrl_t == 'wxBitmapButton':
+        elif isinstance(ctrl, ColourSetter):
             val = ctrl.GetLabel()
         else:
             return False
@@ -702,3 +700,154 @@ class StyleEditor(wx.Dialog):
         # Update the Preview Area
         self.preview.SetStyleTag(tag, self.styles_new[tag])
         self.preview.RefreshStyles()
+
+#-----------------------------------------------------------------------------#
+class ColourSetter(wx.Panel):
+    """Control for setting and selecting a color to describe the
+    various styling of the text control.
+    
+    """
+    def __init__(self, parent, id_, label=wx.EmptyString):
+        """Create the control, it is a composite of a colourSelect and
+        and a text control.
+        @keyword label: the hex string value to go in the text portion
+
+        """
+        wx.Panel.__init__(self, parent, id_)
+
+        # Attributes
+        self._label = label
+        self._txt = wx.TextCtrl(self, value=label, style=wx.TE_CENTER)
+        txtheight = self._txt.GetTextExtent('#000000')[1]
+        txtheight = txtheight + 4
+        self._txt.SetMaxSize((-1, txtheight))
+        self._txt.SetToolTip(wx.ToolTip(_("Enter a hex color value")))
+        self._cbtn = csel.ColourSelect(self, colour=util.HexToRGB(label), 
+                                       size=(20, 20))
+
+        self._DoLayout()
+
+        # Event Handlers
+        self.Bind(csel.EVT_COLOURSELECT, self.OnColour)
+        self._txt.Bind(wx.EVT_KEY_UP, self.OnTextChange)
+        self._txt.Bind(wx.EVT_TEXT_PASTE, self.OnTextChange)
+        self._txt.Bind(wx.EVT_KEY_DOWN, self.OnValidateTxt)
+        self.Bind(wx.EVT_UPDATE_UI, self.OnUpdateUI)
+
+    def __PostEvent(self):
+        """Notify the parent window of any value changes to the control"""
+        evt = ed_event.NotificationEvent(ed_event.edEVT_NOTIFY, self.GetId())
+        wx.PostEvent(self.GetParent(), evt)
+
+    def _DoLayout(self):
+        """Layout the controls"""
+        sizer = wx.BoxSizer(wx.HORIZONTAL)
+        sizer.Add(self._txt, 0, wx.EXPAND)
+        sizer.Add((5, 5), 0)
+        sizer.Add(self._cbtn, 0, wx.ALIGN_LEFT)
+        self.SetSizer(sizer)
+
+    def GetColour(self):
+        """Returns the colour value of the control
+        @return: wxColour object
+
+        """
+        return self._cbtn.GetValue()
+
+    def GetLabel(self):
+        """Gets the hex value from the text control
+        @return: string '#123456'
+        @note: ensures a full 6 digit hex value is returned, padding
+               with zero's where necessary
+
+        """
+        hexstr = self._txt.GetValue()
+        hexstr = hexstr.replace('#', '').replace(' ', '')
+        hexstr = '#' + hexstr + ('0' * (6 - len(hexstr)))
+        return hexstr
+
+    def OnColour(self, evt):
+        """Update the button and text control value
+        when a choice is made in the colour dialog.
+        @param evt: EVT_COLOURSELECT
+
+        """
+        e_id = evt.GetId()
+        e_val = evt.GetValue()[0:3]
+        red = hex(e_val[0])
+        green = hex(e_val[1])
+        blue = hex(e_val[2])
+        hex_str = "#%s%s%s" % (red[2:].zfill(2).upper(),
+                               green[2:].zfill(2).upper(),
+                               blue[2:].zfill(2).upper())
+        self._txt.SetValue(hex_str)
+        self._cbtn.SetValue(wx.Color(e_val[0], e_val[1], e_val[2]))
+        self.__PostEvent()
+
+    def OnTextChange(self, evt=None):
+        """Catch when text changes in the text control and update
+        button accordingly.
+        @keyword evt: event that called this handler
+
+        """
+        hexstr = self._txt.GetValue()
+        hexstr = hexstr.replace('#', '')
+        if len(hexstr) > 6:
+            hexstr = hexstr[:6]
+            self._txt.SetValue(u'#' + hexstr)
+        hexstr = '#' + hexstr + (u'0' * (6 - len(hexstr)))
+        colour = util.HexToRGB(hexstr)
+        self._cbtn.SetValue(colour)
+        self.__PostEvent()
+
+    def OnUpdateUI(self, evt):
+        """Cleanup any bad characters and formating in the display
+        @param evt: UpdateUI
+
+        """
+        txt = self._txt.GetValue().replace('#', '')
+        ret = u''
+        for char in txt:
+            if char not in '0123456789abcdefABCDEF':
+                continue
+            else:
+                ret = ret + char
+        self._txt.SetValue(u'#' + ret)
+
+    def OnValidateTxt(self, evt):
+        """Validate text to ensure only valid hex characters are entered
+        @param evt: wxEVT_KEY_DOWN
+
+        """
+        code = evt.GetKeyCode()
+        if code in [wx.WXK_DELETE, wx.WXK_BACK, wx.WXK_LEFT, wx.WXK_RIGHT] or \
+           evt.CmdDown():
+            evt.Skip()
+            return
+
+        key = unichr(code)
+        if key in "0123456789ABCDEFabcdef#" and \
+           (len(self._txt.GetValue().lstrip("#")) < 6 or \
+            self._txt.GetStringSelection()):
+            evt.Skip()
+
+    def SetLabel(self, label):
+        """Set the label value of the text control
+        @param label: hex string to set label to
+
+        """
+        self._txt.SetValue(label)
+        self.OnTextChange()
+
+    def SetValue(self, colour):
+        """Set the color value of the button
+        @param colour: wxColour or 3 tuple to set colour value to
+
+        """
+        self._cbtn.SetValue(colour)
+        red, green, blue = colour[0:3]
+        hex_str = "#%s%s%s" % (hex(red)[2:].zfill(2).upper(),
+                               hex(green)[2:].zfill(2).upper(),
+                               hex(blue)[2:].zfill(2).upper())
+        self._txt.SetValue(hex_str)
+        self.__PostEvent()
