@@ -32,8 +32,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: synglob.py 340 2007-08-06 22:45:56Z CodyPrecord $"
-__revision__ = "$Revision: 340 $"
+__svnid__ = "$Id: synglob.py 481 2007-09-18 10:01:26Z CodyPrecord $"
+__revision__ = "$Revision: 481 $"
 
 #-----------------------------------------------------------------------------#
 # Dependencies
@@ -77,6 +77,10 @@ LANG_KSH = u'Korn Shell Script'
 ID_LANG_CAML = wx.NewId()
 LANG_CAML = u'Caml'
 
+# Use LEX_CONF
+ID_LANG_APACHE = wx.NewId()
+LANG_APACHE = u'Apache Conf'
+
 # Use LEX_CPP
 ID_LANG_C    = wx.NewId()
 LANG_C = u'C'
@@ -97,6 +101,10 @@ LANG_ESS = u'Editra Style Sheet'
 ID_LANG_EIFFEL = wx.NewId()
 LANG_EIFFEL = u"Eiffel"
 
+# Use LEX_ERLANG
+ID_LANG_ERLANG = wx.NewId()
+LANG_ERLANG = u'Erlang'
+
 # Use LEX_FLAGSHIP
 ID_LANG_FLAGSHIP = wx.NewId()
 LANG_FLAGSHIP = u'FlagShip'
@@ -114,6 +122,8 @@ ID_LANG_HASKELL = wx.NewId()
 LANG_HASKELL = u'Haskell'
 
 # Use LEX_HTML
+ID_LANG_COLDFUSION = wx.NewId()
+LANG_COLDFUSION = u'ColdFusion'
 ID_LANG_HTML = wx.NewId()
 LANG_HTML = u'HTML'
 ID_LANG_JS   = wx.NewId()
@@ -207,6 +217,8 @@ ID_LANG_DIFF = wx.NewId()
 LANG_DIFF = u'Diff File'
 ID_LANG_MAKE  = wx.NewId()
 LANG_MAKE = u'Makefile'
+ID_LANG_PROPS = wx.NewId()
+LANG_PROPS = u'Properties'
 
 # Use LEX_YAML
 ID_LANG_YAML = wx.NewId()
@@ -218,25 +230,28 @@ LANG_YAML = u'YAML'
 EXT_MAP = {
            '68k'                : LANG_68K,
            'ada adb ads a'      : LANG_ADA,
+           'conf htaccess'      : LANG_APACHE,
            'bsh sh configure'   : LANG_BASH,
            'bat cmd'            : LANG_BATCH,
            'c h'                : LANG_C,
-           'd'                  : LANG_D,
-           'patch diff'         : LANG_DIFF,
            'ml mli'             : LANG_CAML,
+           'cfm cfc cfml dbm'   : LANG_COLDFUSION,
            'cc c++ cpp cxx hh h++ hpp hxx' : LANG_CPP,
            'csh'                : LANG_CSH,
            'css'                : LANG_CSS,
+           'd'                  : LANG_D,
+           'patch diff'         : LANG_DIFF,
            'e'                  : LANG_EIFFEL,
+           'erl'                : LANG_ERLANG,
            'ess'                : LANG_ESS,
            'prg'                : LANG_FLAGSHIP,
            'f for'              : LANG_F77,
            'f90 f95 f2k fpp'    : LANG_F95,
-           'ksh'                : LANG_KSH,
-           'java'               : LANG_JAVA,
-           'js'                 : LANG_JS,
            'hs'                 : LANG_HASKELL,
            'htm html shtm shtml xhtml' : LANG_HTML,
+           'java'               : LANG_JAVA,
+           'js'                 : LANG_JS,
+           'ksh'                : LANG_KSH,
            'aux tex sty'        : LANG_LATEX,
            'cl lisp lsp'        : LANG_LISP,
            'lt'                 : LANG_LOUT,
@@ -251,6 +266,7 @@ EXT_MAP = {
            'dfm dpk dpr inc p pas pp' : LANG_PASCAL,
            'cgi pl pm pod'      : LANG_PERL,
            'php php3 phtml phtm' : LANG_PHP,
+           'ini inf reg url cfg cnf' : LANG_PROPS,
            'ai ps'              : LANG_PS,
            'py pyw python'      : LANG_PYTHON,
            'rb rbw rbx'         : LANG_RUBY,
@@ -267,16 +283,19 @@ EXT_MAP = {
 # Maps file types to syntax definitions
 LANG_MAP = {LANG_68K    : (ID_LANG_68K,    stc.STC_LEX_ASM,      'asm68k'),
             LANG_ADA    : (ID_LANG_ADA,    stc.STC_LEX_ADA,      'ada'),
+            LANG_APACHE : (ID_LANG_APACHE, stc.STC_LEX_CONF,     'apache'),
             LANG_BASH   : (ID_LANG_BASH,   stc.STC_LEX_BASH,     'sh'),
             LANG_BATCH  : (ID_LANG_BATCH,  stc.STC_LEX_BATCH,    'batch'),
             LANG_C      : (ID_LANG_C,      stc.STC_LEX_CPP,      'cpp'),
-            LANG_D      : (ID_LANG_D,      stc.STC_LEX_CPP,      'd'),
-            LANG_DIFF   : (ID_LANG_DIFF,   stc.STC_LEX_DIFF,     'diff'),
             LANG_CAML   : (ID_LANG_CAML,   stc.STC_LEX_CAML,     'caml'),
+            LANG_COLDFUSION : (ID_LANG_COLDFUSION, stc.STC_LEX_HTML, 'html'),
             LANG_CPP    : (ID_LANG_CPP,    stc.STC_LEX_CPP,      'cpp'),
             LANG_CSH    : (ID_LANG_CSH,    stc.STC_LEX_BASH,     'sh'),
             LANG_CSS    : (ID_LANG_CSS,    stc.STC_LEX_CSS,      'css'),
+            LANG_D      : (ID_LANG_D,      stc.STC_LEX_CPP,      'd'),
+            LANG_DIFF   : (ID_LANG_DIFF,   stc.STC_LEX_DIFF,     'diff'),
             LANG_EIFFEL : (ID_LANG_EIFFEL, stc.STC_LEX_EIFFEL,   'eiffel'),
+            LANG_ERLANG : (ID_LANG_ERLANG, stc.STC_LEX_ERLANG,   'erlang'),
             LANG_ESS    : (ID_LANG_ESS,    stc.STC_LEX_CSS,      'editra_ss'),
             LANG_F77    : (ID_LANG_F77,    stc.STC_LEX_F77,      'fortran'),
             LANG_F95    : (ID_LANG_F95,    stc.STC_LEX_FORTRAN,  'fortran'),
@@ -300,6 +319,7 @@ LANG_MAP = {LANG_68K    : (ID_LANG_68K,    stc.STC_LEX_ASM,      'asm68k'),
             LANG_PASCAL : (ID_LANG_PASCAL, stc.STC_LEX_PASCAL,   'pascal'),
             LANG_PERL   : (ID_LANG_PERL,   stc.STC_LEX_PERL,     'perl'),
             LANG_PHP    : (ID_LANG_PHP,    stc.STC_LEX_HTML,     'php'),
+            LANG_PROPS  : (ID_LANG_PROPS,  stc.STC_LEX_PROPERTIES, 'props'),
             LANG_PS     : (ID_LANG_PS,     stc.STC_LEX_PS,       'postscript'),
             LANG_PYTHON : (ID_LANG_PYTHON, stc.STC_LEX_PYTHON,   'python'),
             LANG_RUBY   : (ID_LANG_RUBY,   stc.STC_LEX_RUBY,     'ruby'),
@@ -315,16 +335,19 @@ LANG_MAP = {LANG_68K    : (ID_LANG_68K,    stc.STC_LEX_ASM,      'asm68k'),
 
 # Maps language ID's to File Types
 # Used when manually setting lexer from a menu/dialog
-ID_MAP = {ID_LANG_68K    : LANG_68K,    ID_LANG_ADA   : LANG_ADA, 
-          ID_LANG_ASM    : LANG_ASM,    ID_LANG_BASH  : LANG_BASH, 
-          ID_LANG_BATCH  : LANG_BATCH,  
+# TODO maybe dynamically generate this on the fly to remove the need
+#      to update it for each new language.
+ID_MAP = {ID_LANG_68K    : LANG_68K,    ID_LANG_ADA   : LANG_ADA,
+          ID_LANG_APACHE : LANG_APACHE, ID_LANG_ASM   : LANG_ASM,
+          ID_LANG_BASH  : LANG_BASH,    ID_LANG_BATCH : LANG_BATCH,  
           ID_LANG_C      : LANG_C,      ID_LANG_CAML  : LANG_CAML,
+          ID_LANG_COLDFUSION : LANG_COLDFUSION,
           ID_LANG_CPP    : LANG_CPP,    ID_LANG_CSH   : LANG_CSH, 
           ID_LANG_CSS    : LANG_CSS,    ID_LANG_D     : LANG_D,
-          ID_LANG_DIFF   : LANG_DIFF,
-          ID_LANG_EIFFEL : LANG_EIFFEL, ID_LANG_ESS    : LANG_ESS,
+          ID_LANG_DIFF   : LANG_DIFF,   ID_LANG_EIFFEL : LANG_EIFFEL, 
+          ID_LANG_ERLANG : LANG_ERLANG, ID_LANG_ESS    : LANG_ESS,
           ID_LANG_F77    : LANG_F77,    ID_LANG_F95   : LANG_F95,
-          ID_LANG_FLAGSHIP : LANG_FLAGSHIP, ID_LANG_HASKELL: LANG_HASKELL,
+          ID_LANG_FLAGSHIP : LANG_FLAGSHIP, ID_LANG_HASKELL : LANG_HASKELL,
           ID_LANG_HTML   : LANG_HTML,   ID_LANG_JAVA  : LANG_JAVA, 
           ID_LANG_JS     : LANG_JS,     ID_LANG_KSH   : LANG_KSH,
           ID_LANG_LATEX  : LANG_LATEX,  ID_LANG_LISP  : LANG_LISP, 
@@ -334,6 +357,7 @@ ID_MAP = {ID_LANG_68K    : LANG_68K,    ID_LANG_ADA   : LANG_ADA,
           ID_LANG_NASM  : LANG_MASM,    ID_LANG_NSIS   : LANG_NSIS,   
           ID_LANG_OCTAVE : LANG_OCTAVE, ID_LANG_PASCAL : LANG_PASCAL, 
           ID_LANG_PERL   : LANG_PERL,   ID_LANG_PHP    : LANG_PHP,
+          ID_LANG_PROPS  : LANG_PROPS,
           ID_LANG_PS     : LANG_PS,     ID_LANG_PYTHON : LANG_PYTHON,
           ID_LANG_RUBY   : LANG_RUBY,   ID_LANG_SQL    : LANG_SQL,
           ID_LANG_ST     : LANG_ST,     ID_LANG_VB     : LANG_VB,
