@@ -45,8 +45,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__cvsid__ = "$Id: updater.py 267 2007-07-07 10:38:04Z CodyPrecord $"
-__revision__ = "$Revision: 267 $"
+__cvsid__ = "$Id: updater.py 532 2007-09-26 11:59:58Z CodyPrecord $"
+__revision__ = "$Revision: 532 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -61,7 +61,7 @@ from profiler import CalcVersionValue
 import util
 #--------------------------------------------------------------------------#
 # Globals
-DL_REQUEST = ed_glob.home_page + "/?page=download&dist=%s"
+DL_REQUEST = ed_glob.HOME_PAGE + "/?page=download&dist=%s"
 DL_LIN = 'SRC'          # This may need to change in future
 DL_MAC = 'Macintosh'
 DL_SRC = 'SRC'
@@ -128,7 +128,7 @@ class UpdateService(object):
         
         """
         version = re.compile('<\s*a id\="VERSION"[^>]*>(.*?)<\s*/a\s*>')
-        page = self.GetPageText(ed_glob.home_page)
+        page = self.GetPageText(ed_glob.HOME_PAGE)
         found = re.findall(version, page)
         if len(found):
             return found[0] # Should be the first/only match found
@@ -171,7 +171,7 @@ class UpdateService(object):
 
         """
         return self._progress
-
+            
     def GetUpdateFiles(self, dl_to=wx.GetHomeDir()):
         """Gets the requested version of the program from the website
         if possible. It will download the current files for the host system to
@@ -187,13 +187,13 @@ class UpdateService(object):
         if not re.match(verpat, current):
             return False
 
-        if CalcVersionValue(ed_glob.version) < CalcVersionValue(current):
+        if CalcVersionValue(ed_glob.VERSION) < CalcVersionValue(current):
             dl_path = self.GetCurrFileURL()
             dl_file = dl_path.split('/')[-1]
-            dl_to = dl_to + dl_file
+            dl_to = util.GetUniqueName(dl_to, dl_file)
+            blk_sz = 4096
+            read = 0
             try:
-                blk_sz = 4096
-                read = 0
                 webfile = urllib.urlopen(dl_path)
                 fsize = int(webfile.info()['Content-Length'])
                 locfile = open(dl_to, 'wb')
@@ -358,7 +358,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
         
         """
         if self._status[0].isdigit():
-            return CalcVersionValue(self._status) > CalcVersionValue(ed_glob.version)
+            return CalcVersionValue(self._status) > CalcVersionValue(ed_glob.VERSION)
         else:
             return False
 
@@ -448,8 +448,13 @@ class UpdateProgress(wx.Gauge, UpdateService):
         
         """
         jid = delayedResult.getJobID()
-        self.LOG("[updateprog][info] Worker thread exited. ID = %d" % jid)
-        self._checking = self._downloading = False # Work has finished
+
+        try:
+            self.LOG("[updateprog][info] Worker thread exited. ID = %d" % jid)
+            self._checking = self._downloading = False # Work has finished
+        except wx.PyDeadObjectError:
+            return
+
         try:
             result = delayedResult.get()
             if jid == self.ID_CHECKING:
@@ -480,7 +485,7 @@ class UpdateProgress(wx.Gauge, UpdateService):
         self._status = ret
         self.LOG("[updateprog][evt] Update Check Finished: result = " + ret)
         if ret[0].isdigit() and \
-           CalcVersionValue(ret) > CalcVersionValue(ed_glob.version):
+           CalcVersionValue(ret) > CalcVersionValue(ed_glob.VERSION):
             ret = True
         else:
             ret = False
@@ -524,8 +529,14 @@ class DownloadDialog(wx.Frame):
         #---- Layout ----#
         self.CreateStatusBar(2)
         self._sizer = wx.GridBagSizer()
-        bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_DOWNLOAD_DLG), 
-                                       wx.ART_OTHER)
+        bmp = wx.ArtProvider.GetBitmap(str(ed_glob.ID_WEB), wx.ART_TOOLBAR)
+        mdc = wx.MemoryDC(bmp)
+        tmp_bmp = wx.Image(ed_glob.CONFIG['SYSPIX_DIR'] + u"editra.png", 
+                           wx.BITMAP_TYPE_PNG)
+        tmp_bmp.Rescale(20, 20, wx.IMAGE_QUALITY_HIGH)
+        mdc.DrawBitmap(tmp_bmp.ConvertToBitmap(), 11, 11)
+        bmp = mdc.GetAsBitmap()
+        mdc.Destroy()
         bmp = wx.StaticBitmap(panel, wx.ID_ANY, bmp)
         self._sizer.AddMany([((10, 10), (0, 0)), (bmp, (1, 1), (3, 2)),
                              ((5, 5), (1, 3)),
