@@ -38,8 +38,8 @@
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: util.py 353 2007-08-17 10:27:29Z CodyPrecord $"
-__revision__ = "$Revision: 353 $"
+__svnid__ = "$Id: util.py 537 2007-09-26 13:14:41Z CodyPrecord $"
+__revision__ = "$Revision: 537 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -219,15 +219,29 @@ def SetClipboardText(txt):
 BOM = { 'utf-8' : codecs.BOM_UTF8,
         'utf-16-be' : codecs.BOM_UTF16_BE,
         'utf-16-le' : codecs.BOM_UTF16_LE,
-#        (codecs.BOM_UTF32_BE, 'utf-32-be'),
-#        (codecs.BOM_UTF32_LE, 'utf-32-le'),
         'utf-7' : '+\v8-',
         'latin-1' : '',
         'ascii' : '' }
 
-ENC = [ 'utf-8', 'utf-16-be', 'utf-16-le', 
+# When no BOM is present this determines decode test order
+ENC = [ 'utf-8', 'utf-7', 'latin-1', 'utf-16-be', 'utf-16-le', 'ascii']
   #      'utf-32-be', 'utf-32-le', 
-        'utf-7', 'latin-1', 'ascii']
+
+def DecodeString(str2decode):
+    """Decode a given string if possible and return that string
+    @param str2decode: the string to decode
+
+    """
+    decoded = str2decode
+    for enc in ENC:
+        try:
+            decoded = str2decode.decode(enc)
+        except (UnicodeDecodeError, UnicodeWarning):
+            continue
+        else:
+            break
+
+    return decoded
 
 def GetDecodedText(fname):
     """Gets the text from a file and decodes the text using
@@ -245,6 +259,19 @@ def GetDecodedText(fname):
         return -1
     else:
         decoded = None
+
+        # First look for a bom byte
+        bbyte = None
+        for e, b in BOM.iteritems():
+            if txt.startswith(b) and e not in ['ascii', 'latin-1']:
+                bbyte = e
+
+        tenc = ENC
+        if bbyte:
+            if bbyte in tenc:
+                tenc.remove(bbyte)
+            tenc.insert(0, bbyte)
+
         for enc in ENC:
             try:
                 decoded = txt.decode(enc)
@@ -252,6 +279,7 @@ def GetDecodedText(fname):
                 continue
             else:
                 break
+
         if 'enc' not in locals():
             enc = u''
         if decoded:
@@ -329,12 +357,14 @@ def GetFileModTime(file_name):
 
 def GetFileReader(file_name, enc='utf-8'):
     """Returns a file stream reader object for reading the
-    supplied file name. It returns a utf-8 reader if the host
-    system supports it other wise it will return an ascii reader.
+    supplied file name. It returns a file reader using the encoding
+    (enc) which defaults to utf-8. If lookup of the reader fails on
+    the host system it will return an ascii reader.
     If there is an error in creating the file reader the function 
     will return a negative number.
     @param file_name: name of file to get a reader for
     @keyword enc: encoding to use for reading the file
+    @return file reader, or int if error.
 
     """
     try:
@@ -345,14 +375,15 @@ def GetFileReader(file_name, enc='utf-8'):
     try:
         reader = codecs.lookup(enc)[2](file_h)
     except (LookupError, IndexError):
-        dev_tool.DEBUGP('[file_reader] Failed to get UTF-8 Reader')
+        dev_tool.DEBUGP('[file_reader] Failed to get %s Reader' % enc)
         reader = file_h
     return reader
 
 def GetFileWriter(file_name, enc='utf-8'):
     """Returns a file stream writer object for reading the
-    supplied file name. It returns a utf-8 reader if the host
-    system supports it other wise it will return an ascii reader.
+    supplied file name. It returns a file writer in the supplied
+    encoding if the host system supports it other wise it will return 
+    an ascii reader. The default will try and return a utf-8 reader.
     If there is an error in creating the file reader the function 
     will return a negative number.
     @param file_name: path of file to get writer for
@@ -367,7 +398,7 @@ def GetFileWriter(file_name, enc='utf-8'):
     try:
         writer = codecs.lookup(enc)[3](file_h)
     except (LookupError, IndexError):
-        dev_tool.DEBUGP('[file_writer] Failed to get UTF-8 Writer')
+        dev_tool.DEBUGP('[file_writer] Failed to get %s Writer' % enc)
         writer = file_h
     return writer
 
@@ -380,6 +411,26 @@ def GetPathChar():
     else:
         return u"/"
 
+def GetUniqueName(path, name):
+    """Make a file name that will be unique in case a file of the
+    same name already exists at that path.
+    @param path: Root path to download folder
+    @param name: desired file name base
+    @return: string
+
+    """
+    tmpname = os.path.join(path, name)
+    if os.path.exists(tmpname):
+        ext = name.split('.')[-1]
+        fbase = name[:-1 * len(ext) - 1]
+        inc = len([x for x in os.listdir(path) if x.startswith(fbase)])
+        tmpname = os.path.join(path, "%s-%d.%s" % (fbase, inc, ext))
+        while os.path.exists(tmpname):
+            inc = inc + 1
+            tmpname = os.path.join(path, "%s-%d.%s" % (fbase, inc, ext))
+
+    return tmpname
+
 def GetPathName(path):
     """Gets the path minus filename
     @param path: full path to get base of
@@ -411,12 +462,10 @@ def GetIds(obj_lst):
     """Gets a list of IDs from a list of objects
     @param obj_lst: list of objects to get ids from
     @return: list of ids
+    @note: I believe this is no longer used anywhere and may be removed soon
 
     """
-    id_list = []
-    for obj in obj_lst:
-        id_list.append(obj.GetId())
-    return id_list
+    return [obj.GetId() for obj in obj_lst]
 
 def ResolvAbsPath(rel_path):
     """Takes a relative path and converts it to an
@@ -452,7 +501,7 @@ def HasConfigDir(loc=u""):
     """
     pchar = GetPathChar()
     if os.path.exists(u"%s%s.%s%s%s" % (wx.GetHomeDir(), pchar,
-                                        ed_glob.prog_name, pchar, loc)):
+                                        ed_glob.PROG_NAME, pchar, loc)):
         return True
     else:
         return False
@@ -462,7 +511,7 @@ def MakeConfigDir(name):
     @param name: name of config directory to make in user config dir
 
     """
-    config_dir = wx.GetHomeDir() + GetPathChar() + u"." + ed_glob.prog_name
+    config_dir = wx.GetHomeDir() + GetPathChar() + u"." + ed_glob.PROG_NAME
     try:
         os.mkdir(config_dir + GetPathChar() + name)
     finally:
@@ -477,7 +526,7 @@ def CreateConfigDir():
     #---- Resolve Paths ----#
     pchar = GetPathChar()
     prof_dir = ed_glob.CONFIG['PROFILE_DIR']
-    config_dir = u"%s%s.%s" % (wx.GetHomeDir(), pchar, ed_glob.prog_name)
+    config_dir = u"%s%s.%s" % (wx.GetHomeDir(), pchar, ed_glob.PROG_NAME)
     profile_dir = u"%s%sprofiles" % (config_dir, pchar)
     config_file = u"%sdefault.ppb" % prof_dir
     loader =  u"%s.loader2" % prof_dir
@@ -517,7 +566,7 @@ def ResolvConfigDir(config_dir, sys_only=False):
     if not sys_only:
         # Try to look for a user dir
         user_config = u"%s%s.%s%s%s" % (wx.GetHomeDir(), path_char,
-                                        ed_glob.prog_name, path_char, 
+                                        ed_glob.PROG_NAME, path_char, 
                                         config_dir)
         if os.path.exists(user_config):
             return user_config + path_char
@@ -563,7 +612,7 @@ def ResolvConfigDir(config_dir, sys_only=False):
         elif pro_path == "":
             pro_path = os.getcwd()
             pieces = pro_path.split(path_char)
-            if pieces[-1] not in [ed_glob.prog_name.lower(), ed_glob.prog_name]:
+            if pieces[-1] not in [ed_glob.PROG_NAME.lower(), ed_glob.PROG_NAME]:
                 pro_path = path_char.join(pieces[:-1])
         else:
             pro_path = ResolvAbsPath(pro_path)
